/*
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package nat;
//***  java.io ***
import java.io.File;
import java.io.RandomAccessFile;
import java.io.BufferedWriter;
import java.io.PrintWriter;
import java.io.FileWriter;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.w3c.dom.Document;
// *** writer2latex ***
import writer2latex.Application;
import writer2latex.office.MIMETypes;
//import writer2latex.util.Misc;
// *** gestionnaires ***
import gestionnaires.GestionnaireErreur;
// *** Autres ***
//import javax.swing.text.BadLocationException;
//import javax.swing.text.StyleConstants;

public class Convertisseur 
{
	private String source;
	private String cible;
	private int nbCars;
	private int nbMots;
	private int nbPhrases;
	private long tempsExecution;
	private int format;
	private String DTD;
	
	public static final int TEXTE = 1;
	public static final int OPENOFFICE = 2;
	public static final int WINDOB = 0;

	public Convertisseur()
	{
		
	}
	
	public Convertisseur(String src, String c)
	{
		source=src;
		cible=c;
	}
	
	public void SetSource(String src)
	{
		source=src;
	}
	public void SetDTD(String laDTD)
	{
		DTD=laDTD;
	}
	public void SetCible(String c)
	{
		cible=c;
	}
	
	public void setFormat(int f)
	{
		format = f;
	}
	
	public boolean Convertir(GestionnaireErreur gest)
	{
		tempsExecution = System.currentTimeMillis();
		gest.AfficheMessage("Dbut de la conversion du document ... ok\n");
		boolean retour=true;
		nbCars = 0;
		nbMots = 0;
		nbPhrases = 0;
		switch (format)
		{
		case OPENOFFICE:
			Application app = new Application();
			app.setsOutputFormat("xhtml");
			app.settoMime(MIMETypes.XHTML_MATHML);
			app.setsFileName(source);
			app.setsOutFileName("tmp.xhtml");
			app.setsOutPathName("");//new File(source).getParent());
	       /*sFullOutFileName;
	        if (i<args.length) { sFullOutFileName = getArg(i,args); }
	        else { sFullOutFileName = Misc.removeExtension(sFileName); }
	        if (sFullOutFileName.endsWith(File.separator)) { // directory only
	            sOutPathName=sFullOutFileName;
	            sOutFileName = (new File(sFileName)).getName();
	        }
	        else { // directory and filename
	            File f = new File(sFullOutFileName);
	            sOutPathName = f.getParent();
	            if (sOutPathName==null) { sOutPathName=""; } else { sOutPathName+=File.separator; }
	            sOutFileName = f.getName();
	        }
	        sOutFileName = Misc.removeExtension(sOutFileName);
            //app.parseCommandLine(args);*/
            System.out.println("Dbut de la conversion en XHTML...");
            app.doConversion();
            System.out.println("Conversion XHTML termine!");
            XHTML2FormatInterne("tmp.xhtml", gest); 
			break;
			
		case TEXTE:
		
			try
		      {
			  gest.AfficheMessage("** Ouverture du fichier source: " + source + " ...");
		      RandomAccessFile raf = new RandomAccessFile(source, "r");
		      gest.AfficheMessage("ok\n** Conversion du fichier source ..." );
		      PrintWriter fcible =  new PrintWriter(new BufferedWriter(new FileWriter(cible,false)));
		      //on met les enttes au fichier xml
		      fcible.println("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>");
		      fcible.println("<!DOCTYPE doc:doc SYSTEM \"" + "./xsl/" +DTD +"\">");
		      fcible.println("<doc:doc xmlns:doc=\"espaceDoc\">");
	
		      String ligne;
		      int i=0;
		      while ( (ligne = raf.readLine()) != null )
			  	{
		    	  nbPhrases++;
			      fcible.println("\t<phrase>\n\t\t<lit>");
		    	  String [] mots=ligne.split(" ");
		    	  nbMots = nbMots + mots.length;
		    	  while (i<mots.length)
		    	  {
		    	   if (mots[i].endsWith(".")||mots[i].endsWith(",")||mots[i].endsWith(";")||mots[i].endsWith("!")||mots[i].endsWith("?")||mots[i].endsWith(":"))
		    	   {
		    		   fcible.println("\t\t\t<mot>" + mots[i].substring(0,mots[i].length()-1) +"</mot>");
		    		   fcible.println("\t\t\t<ponctuation>" + mots[i].charAt(mots[i].length()-1) + "</ponctuation>");
		    		   nbCars = nbCars + mots[i].length() + 1;
		    	   }
		    	   else
		    	   {
		    		   fcible.println("\t\t\t<mot>" + mots[i] +"</mot>");//\t\t\t<espace></espace>");
		    		   nbCars = nbCars + mots[i].length();
		    	   }    	   
		    	   i++;
		    	  }
		    	  i=0;
		    	  fcible.println("\t\t</lit>\n\t</phrase>");
		  	    }
		      fcible.println("</doc:doc>");
		      fcible.close();
		      gest.AfficheMessage("\nLe document contient " + nbPhrases +" paragraphes, " + nbMots + " mots et " + nbCars +" caractres.");
		      tempsExecution = System.currentTimeMillis() - tempsExecution;
		      gest.AfficheMessage("ok\n----Conversion termine en " + tempsExecution + " msec.\n");
		      retour = true;
		      }
		    catch (Exception e)  
		      {
		       gest.setException(e);
		       gest.GestionErreur();
		       retour = false;
		      }
		    break;
		    
		}
		return retour;
	}
	
	public void XHTML2FormatInterne(String source, GestionnaireErreur gestErreur)
	{
		/*gestErreur.AfficheMessage("ok\n** Cration de la fabrique (DocumentBuilderFactory) ...");
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        //configuration de la fabrique
        factory.setNamespaceAware(true);
        factory.setValidating(true);
        factory.setIgnoringElementContentWhitespace(true);
        factory.setIgnoringComments(true);
        factory.setIgnoringElementContentWhitespace(false);
        try 
        {
            DocumentBuilder builder = factory.newDocumentBuilder();
            gestErreur.AfficheMessage("ok\n** Parsage du document d'entre XHTML avec SAX ...");
            builder.setErrorHandler(gestErreur);
            Document doc = builder.parse(new File(source));
            doc.setStrictErrorChecking(true);
            gestErreur.AfficheMessage("ok\n** Initialisation et lecture de la feuille de style de conversion...");
            TransformerFactory transformFactory = TransformerFactory.newInstance();
            StreamSource styleSource = new StreamSource(new File("filtreConversion"));
            // lire le style
            
            Transformer transform = transformFactory.newTransformer(styleSource);
            // conformer le transformeur au style
            DOMSource in = new DOMSource(doc);
            gestErreur.AfficheMessage("ok\n** Cration du fichier au format interne ...");
            // Cration du fichier de sortie
            File file = new File(cible);
            ///Result resultat = new StreamResult(fichier);
            StreamResult out = new StreamResult(file);
            gestErreur.AfficheMessage("ok\n** Transformation du document interne...");
            transform.transform(in, out);
            // transformer selon le style 
            //tempsExecution = System.currentTimeMillis() - tempsExecution;
            //gestErreur.AfficheMessage("ok\n----Transcription termine en " + tempsExecution/1000 +"," + tempsExecution%1000+" sec.\n");
        }
        catch (Exception e)  
        {
           gestErreur.setException(e);
           gestErreur.GestionErreur();
        }*/
	}
}
