/*
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package nat;

import javax.swing.JTextPane;
import gestionnaires.GestionnaireErreur;
import nat.Transcodeur;
import nat.Convertisseur;
import ui.FenetrePrinc;

public class Nat 
{
	//configuration des filtres
	private String DTD = "./mmlents/windob.dtd";
	private String XSL = "./xsl/xsl.xsl";
	private String XSL_g1 = "fr-g1.xsl";
	private String XSL_g2 = "fr-g2.xsl";
	private String XSL_Maths = "fr-maths.xsl";
	
	
	private boolean abreger = true;
	private boolean brailleMath = true;
	private boolean brailleLit = true;
	
	//configuration du comportement aprs transcription
	private boolean ouvreEditeurApresTranscription = true;
	private String editeur = null; //si null: editeur interne
	
	//configuration de l'interface
	private boolean editeurEnBraille =true;
	
	private String licence;
	
	
	public Nat()
	{
		licence = getLicence("","");
	}
	
	public String getDTD(){	return DTD;}
	public String getXSL(){return XSL;}
	public boolean getAbreger(){return abreger;}
	public void setAbreger(boolean a){this.abreger = a;}
	public boolean getTraiterMaths(){return brailleMath;}
	public void setTraiterMaths(boolean m){this.brailleMath = m;}
	public boolean getTraiterLiteraire(){return brailleLit;}
	public void setTraiterLiteraire(boolean l){this.brailleLit = l;}
	public String getXSL_g1(){return XSL_g1;}
	public String getXSL_g2(){return XSL_g2;}
	public String getXSL_maths(){return XSL_Maths;}
	
	public boolean getOuvrirEditeur(){return ouvreEditeurApresTranscription;} 
	public String getEditeur(){return editeur;}
	
	public boolean getEditeurEnBraille(){return editeurEnBraille;}
	//public String getLicence(){return licence;}
	
	public void chargeOptions(String fichOptions)
	{
		
	}
	
	public String getLicence(String prefixe, String suffixe)
	{
		return prefixe + " * NAT - An universal Translator\n" +
		 "* Copyright (C) 2005 Bruno Blanchard, Bruno Mascret\n" +
		 "* Contact: bmascret@free.fr\n" +
		 "* \n" +
		 "* This program is free software; you can redistribute it and/or\n" +
		 "* modify it under the terms of the GNU General Public License\n" +
		 "* as published by the Free Software Foundation; either version 2\n" +
		 "* of the License.\n" +
		 "* \n" +
		 "* This program is distributed in the hope that it will be useful,\n" +
		 "* but WITHOUT ANY WARRANTY; without even the implied warranty of\n" +
		 "* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" +
		 "* GNU General Public License for more details.\n" +
		 "* \n" +
		 "* You should have received a copy of the GNU General Public License\n" +
		 "* along with this program; if not, write to the Free Software\n" +
		 "* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n" +
		 suffixe;
	
	}

    public static void main (String argv [])
    {
		Nat nat = new Nat();
    	Transcodeur transcodeur = new Transcodeur(nat);
    	Convertisseur convertisseur = new Convertisseur("source.txt", "tmp.xml");
    	convertisseur.SetDTD(nat.getDTD());
    	
    	if (argv.length <1)
    	{
    		System.out.println("\nUsage: nat  [--gui]  fichierSource fichierCible\n");
    	}
    	else
    	{
	    	 if (argv[0].compareTo("--gui")==0)
	    	 {
	 	    	FenetrePrinc fenetre = new FenetrePrinc(convertisseur, transcodeur, nat);
		    	fenetre.setFiltre(nat.getXSL());
	    		 fenetre.pack();
	 	    	 fenetre.setVisible(true);
	    	 }
	    	 else if (argv.length ==1)
	     	 {
	      		System.out.println("\nUsage: nat  [--gui]  fichierSource fichierCible\n");
	     	 }
	    	 else
	    	 {
	 			if ((argv[0].length()<1)||(argv[1].length()<1))
				{
					System.out.println("Entrez un fichier source et un fichier cible");
				}
				else
				{
					GestionnaireErreur gestErreur = new GestionnaireErreur(null,new JTextPane());
					if (argv[0].endsWith(".txt"))
					{
						convertisseur.setFormat(Convertisseur.TEXTE);
						convertisseur.SetSource(argv[0]);
				    	if(convertisseur.Convertir(gestErreur))
				    		{
					    	 transcodeur.Transcrire("tmp.xml",nat.getXSL(),argv[1], gestErreur);
				    		}
					}
					else if (argv[0].endsWith(".sxw"))
					{
						convertisseur.setFormat(Convertisseur.OPENOFFICE);
						convertisseur.SetSource(argv[0]);
				    	if(convertisseur.Convertir(gestErreur))
				    		{
				    		gestErreur.AfficheMessage("format OO, convertit");
					    	 //transcodeur.Transcrire("tmp.xml",filtre.getText(),fichierSortie, gestErreur);
				    		}
					}
					else
					{
						transcodeur.Transcrire(argv[0],nat.getXSL(),argv[1], gestErreur);
					}
				}
	    	 }
    	} 
    } 
}
