/*
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package nat;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
//import javax.xml.parsers.FactoryConfigurationError;
//import javax.xml.parsers.ParserConfigurationException;
//import org.xml.sax.SAXException;
//import org.xml.sax.SAXParseException;
import org.w3c.dom.Document;
//import org.w3c.dom.DOMException;
import javax.xml.transform.Transformer;
//import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
//import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import gestionnaires.GestionnaireErreur;

public class Transcodeur 
{	
	private long tempsExecution;
	private Nat nat;
	
	public Transcodeur(Nat nat)
	{
		this.nat = nat;
	}
	
	private void CreerFiltre(String filtre, GestionnaireErreur gestErreur)
	{
		try
		{
			FileWriter fichierXSL = new FileWriter(filtre);
			fichierXSL.write("<?xml version='1.0' encoding=\"ISO-8859-1\" ?>\n" +
			"<!DOCTYPE xsl:stylesheet SYSTEM \"" + nat.getDTD() +"\"" +
			"\n[\n" +
			"<!ENTITY % table_braille PUBLIC \"table braille\" \"./tablesBraille/Brltab.ent\">\n" +
			"%table_braille;\n" +
			"<!ENTITY quad    \"&ThickSpace;\"> <!-- espace -->\n" +
			"<!ENTITY neq     \"&ne;\"> <!-- different de -->\n" +
			"<!ENTITY epsilon \"&epsiv;\"> <!-- epsilon -->\n" +
			"<!ENTITY empty \"&emptyv;\"> <!-- endemble vide -->\n" +
			"<!ENTITY ldots   \"&mldr;\"> <!-- points de suspension -->\n" +
			"<!ENTITY hat     \"&Hat;\"> <!-- signe d'angle -->\n" +
			"<!ENTITY espace  \"&#254;\"><!-- espace  generer-->\n" +
			"<!ENTITY coupe   \"&#255;\"><!-- endroit ou on peut couper un equation-->\n" +
			"]>\n" +
			"<xsl:stylesheet version=\"1.0\"\n" +
			"xmlns:xsl='http://www.w3.org/1999/XSL/Transform'\n" +
			"xmlns:saxon='http://icl.com/saxon'\n" +
			"xmlns:m='http://www.w3.org/1998/Math/MathML'\n" +
			"xmlns:lit='espacelit'\n" +
			"xmlns:doc='espaceDoc'>\n" +
			"<xsl:output method=\"text\" encoding=\"ISO-8859-1\" indent=\"no\"/>\n" +
			"<!-- Bruno :je dcommente la ligne suivante et j'ajoute les lments o il faut virer les espaces -->\n" +
			"<xsl:strip-space elements = \"doc:doc lit espace phrase mot ponctuation m:* m:math m:semantics m:mrow\" />" +
			"\n<!-- *************** PARAMETRES ***************** -->\n" +
			"<xsl:param name=\"debut\"/><!--$$Debut</xsl:param>  caracteres de debut de document -->\n" +
			"<xsl:param name=\"avant\"/><!--$$Fin</xsl:param>  caracteres de debut d'expression -->\n" +
			"<xsl:param name=\"apres\"/> <!-- caracteres de fin d'expression -->\n" +
			"<xsl:param name=\"fin\"/> <!-- caracteres de fin de document -->\n" +
			"<xsl:param name=\"norme\">1</xsl:param> <!-- choix de norme braille -->" +
			"\t<!-- norme= 1 pour nouvelle norme sept/2001, norme = 2 pour norme ancienne -->\n" +
			"<xsl:param name=\"longueur\">30</xsl:param> <!-- longueur en caracteres du terminal ou imprimante braille -->\n" +
			"<xsl:param name=\"coupons\">1</xsl:param>\n" +
			"\t<!-- coupons = 1 si on coupe l'equation, 0 sinon, defaut a 1 -->\n" +
			"<xsl:param name=\"abrege\">1</xsl:param>\n" +
			"\t<!-- abrege = 1 si braille abrege, 0 sinon, defaut a 1 -->\n" +
			"\n<!-- *************** VARIABLES ******************* -->\n" +
			"<!-- variables pour eviter que les translate plantent en mettant directement les entits -->\n" +
			"<!-- pb dcouvert avec le codeUS o pt3=' -->\n" +
			"<xsl:variable name=\"apos\">'</xsl:variable>\n" +
			"<xsl:variable name=\"quot\">\"</xsl:variable>\n");

			if (nat.getTraiterLiteraire())
			{
				fichierXSL.write("<!--Litraire-->\n");
				if (nat.getAbreger())
				{
					fichierXSL.write("<xsl:include href=\"" + nat.getXSL_g2() +"\"/>\n");
				}
				else
				{
					fichierXSL.write("<xsl:include href=\"" + nat.getXSL_g1() +"\"/>\n");
				}
			}
			if (nat.getTraiterMaths())
			{
				fichierXSL.write("<!-- mathmatiques -->\n<xsl:include href=\"" + nat.getXSL_maths() +"\"/>");
			}
			
			fichierXSL.write("</xsl:stylesheet>");
			fichierXSL.close();
		}
		catch (IOException e)
		{
			gestErreur.AfficheMessage("\nerreur dans: " + e);
		}
	}
	
	public void Transcrire(String entree, String filtre, String sortie, GestionnaireErreur gestErreur)
	{
		tempsExecution = System.currentTimeMillis();
		//Exception exception = null;
		gestErreur.AfficheMessage("\nDbut de la transcription ... ok\n");
		gestErreur.AfficheMessage("** Fichiers :\n Fichier d'entree:" + entree + "\n Filtre :" + filtre);
		gestErreur.AfficheMessage("\n** Mise en place du scnario de transcription...");
		CreerFiltre(filtre, gestErreur);
		gestErreur.AfficheMessage("ok\n** Cration de la fabrique (DocumentBuilderFactory) ...");
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        //configuration de la fabrique
        factory.setNamespaceAware(true);
        factory.setValidating(true);
        factory.setIgnoringElementContentWhitespace(true);
        factory.setIgnoringComments(true);
        factory.setIgnoringElementContentWhitespace(false);
        try 
        {
            DocumentBuilder builder = factory.newDocumentBuilder();
            gestErreur.AfficheMessage("ok\n** Parsage du document d'entre avec SAX ...");
            builder.setErrorHandler(gestErreur);
            Document doc = builder.parse(new File(entree));
            doc.setStrictErrorChecking(true);
            gestErreur.AfficheMessage("ok\n** Initialisation et lecture de la feuille de style ...");
            TransformerFactory transformFactory = TransformerFactory.newInstance();
            StreamSource styleSource = new StreamSource(new File(filtre));
            // lire le style
            
            Transformer transform = transformFactory.newTransformer(styleSource);
            // conformer le transformeur au style
            DOMSource in = new DOMSource(doc);
            gestErreur.AfficheMessage("ok\n** Cration du fichier de sortie ...");
            // Cration du fichier de sortie
            File file = new File(sortie);
            ///Result resultat = new StreamResult(fichier);
            StreamResult out = new StreamResult(file);
            gestErreur.AfficheMessage("ok\n** Transformation du document ...");
            transform.transform(in, out);
            // transformer selon le style 
            tempsExecution = System.currentTimeMillis() - tempsExecution;
            gestErreur.AfficheMessage("ok\n----Transcription termine en " + tempsExecution/1000 +"," + tempsExecution%1000+" sec.\n");
        }
        catch (Exception e)  
        {
           gestErreur.setException(e);
           gestErreur.GestionErreur();
        }
	}

}
/*
catch (FileNotFoundException e)
{
	exception = e;
	System.out.println(" Erreur lors du chargement d'un fichier: " + e.getMessage());
}
catch (TransformerConfigurationException e) 
{
   System.out.println (" Erreur lors du chargement de la configuration du convertisseur: " + e.getMessage() );
   Throwable x = e;
   if (e.getException() != null) x = e.getException();
   x.printStackTrace();
} 
catch (TransformerException e) 
{
   System.out.println (" Erreur du convertisseur: " + e.getMessage() );
   Throwable x = e;
   if (e.getException() != null) x= e.getException();
   x.printStackTrace();
 }
catch (SAXException e)
{
   Exception  x = e;
   if (e.getException() != null) x = e.getException();
   System.out.println (" Erreur du parser SAX: " + x.getMessage() );
   x.printStackTrace();
} 
catch (ParserConfigurationException e)
{
	System.out.println (" Erreur de configuration du parser: " + e.getMessage() );
	e.printStackTrace();
} */
/*import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;

public class GestionnaireContenu implements ContentHandler {
  public GestionnaireDocument() {
  }
  public void characters(char[] ch, int start, int length) {
    System.out.println("CONTENU TEXTUEL :\n" + new String(ch));
  }
  public void endDocument() {
    System.out.println("FIN DOCUMENT");
  }
  public void endElement(String uri, String localName, String qName) {
    System.out.println("FIN ELEMENT (" + qName + ")");
  }
  public void endPrefixMapping(String prefix) {
    System.out.println("FIN PREFIXE ESPACE DE NOMS (" + prefix + ")");
  }
  public void ignorableWhitespace(char[] ch, int start, int length) {
    System.out.println("ESPACE BLANC : ");
    System.out.println("\tChaine : '" + new String(ch) + "'");
  }
  public void processingInstruction(String target, String data) {
    System.out.println("INSTRUCTION DE TRAITEMENT : ");
    System.out.println("\tCible : " + target);
    System.out.println("\tContenu : " + data);
  }
  public void setDocumentLocator(Locator locator) {
    System.out.println("LOCALISTAION : ");
    System.out.println("\tNom de classe : " + locator.getClass().getName());
    System.out.println("\tN de colonne : " + locator.getColumnNumber());
    System.out.println("\tN de ligne : " + locator.getLineNumber());
    System.out.println("\tID Public : " + locator.getPublicId());
    System.out.println("\tID Systme : " + locator.getSystemId());
  }
  public void skippedEntity(String name) {
    System.out.println("ENTITE SAUTEE : ");
    System.out.println("\tNom : " + name);
  }
  public void startDocument() {
    System.out.println("DEBUT DOCUMENT");
  }
  public void startElement(String uri, String localName, String qName,
      Attributes attributes) {
    System.out.println("DEBUT ELEMENT (" + qName + ")");
    System.out.println("\tAdresse URI : " + uri);
    System.out.println("\tNom local : " + localName);
    System.out.println("\tNom qualifi : " + qName);
    System.out.println("\tAttributs : " + attributes.getLength());
    for (int i = 0; i < attributes.getLength(); i++) {
      System.out.print("\t\t" + attributes.getQName(i));
      System.out.println(" = " + attributes.getValue(i));
    }
  }
  public void startPrefixMapping(String prefix, String uri) {
    System.out.println("DEBUT PREFIXE ESPACE DE NOMS : ");
    System.out.println("\tPrfixe : " + prefix);
    System.out.println("\tURI : " + uri);
  }
}*/