/*
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package ui;

import java.io.FileWriter;
import java.io.IOException;
import java.io.RandomAccessFile;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JTextField;
import java.awt.Dimension;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

import nat.Nat;

public class ConfTableBraille extends JFrame implements ActionListener
{

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private JTable table;
	private JLabel nomTable;
	private JScrollPane scrollTable;
	private JButton btEnregistrer = new JButton("Enregistrer");
	private JButton btEnregistrerSous = new JButton("Enregistrer sous...");
	private JTextField texteEnregistrerSous;
	private JButton btQuitter = new JButton("Quitter");
	private String fichierTable;
	private String[] lesColonnes = new String[]{"Braille", "Caractre", "Code ASCII"};
	private String[][] donnees;
	private Nat nat;
	
	public ConfTableBraille(String fichierTable, Nat nat)
	{
		this.nat = nat;
		this.fichierTable = "./xsl/tablesBraille/" + fichierTable + ".ent";
		texteEnregistrerSous = new JTextField("votre table", 10);
		nomTable = new JLabel("Table " + fichierTable);
		//on ouvre le fichier et on remplit la table
		AfficheTable();
		table = new JTable(donnees,lesColonnes);
		scrollTable = new JScrollPane (table);
		scrollTable.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
		scrollTable.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		scrollTable.setPreferredSize(new Dimension(300,350));
		
		JPanel pTable = new JPanel();
		pTable.add(scrollTable);
		pTable.setPreferredSize(new Dimension(350,400));
		
		JPanel lesBoutons = new JPanel();
		btEnregistrer.addActionListener(this);
		btQuitter.addActionListener(this);
		btEnregistrerSous.addActionListener(this);
		lesBoutons.add(btEnregistrer);
		lesBoutons.add(btEnregistrerSous);
		lesBoutons.add(texteEnregistrerSous);
		lesBoutons.add(btQuitter);
		add("North", nomTable);
		add("Center",pTable);
		add("South",lesBoutons);
		setSize(600,450);
	}
	
	public void actionPerformed(ActionEvent evt)
	{
		if (evt.getSource()==btEnregistrer)
		{
			Enregistrer();
		}
		else if (evt.getSource()==btQuitter)
		{
			this.dispose();
		}
		else if(evt.getSource()==btEnregistrerSous)
		{
			EnregistrerSous();
		}
	}
	
	private void Enregistrer()
	{
		try
		{
			int i;
			FileWriter raf = new FileWriter(fichierTable);
			raf.write(nat.getLicence("<!--\n","-->\n"));
			for (i=0; i<donnees.length; i++)//length - 1 car il y a une ligne en plus je sais pas pq
			{
				raf.write("<!ENTITY " + donnees[i][0] + " \"&" + donnees[i][1] + ";\">\n");
			}
			raf.close();
		}
		catch (IOException e)
		{
			System.out.println("erreur dans: " + e);
		}
	}
	
	private void EnregistrerSous()
	{
		fichierTable = "./xsl/tablesBraille/" + texteEnregistrerSous.getText() + ".ent";
		Enregistrer();
	}
	
	private boolean AfficheTable()
	{
	    boolean retour = true;
		try
	      {
		      RandomAccessFile raf = new RandomAccessFile(fichierTable, "r");
		      String ligne;
		      String[] enregistrement;
		      int i=1;
		      
		      ligne = raf.readLine();
		      //on cherche le dbut des entites
		      while(!ligne.startsWith("<!ENTITY") && ligne!=null)
		      {
		    	  ligne = raf.readLine();
		      }
		      if (ligne==null)
		      {
		    	  System.out.println("Le fichier" + fichierTable + "n'est pas un fichier valide");
		    	  retour =false;
		      }
		      else
		      {
		    	  donnees = new String[64][3];
		    	  enregistrement = ligne.split(" ");
		    	  //donnees[i] = new String[2];
		    	  donnees[0][0] = enregistrement[1];
		    	  donnees[0][1] = enregistrement[2].substring(2, enregistrement[2].length()-3);
		    	  donnees[0][2] = enregistrement[2].substring(2, enregistrement[2].length()-3);

			      while ( (ligne = raf.readLine()) != null && i<donnees.length)
				  	{
			    	  enregistrement = ligne.split(" ");
			    	  //donnees[i] = new String[2];
			    	  donnees[i][0] = enregistrement[1];
			    	  donnees[i][1] = enregistrement[2].substring(2, enregistrement[2].length()-3);
			    	  donnees[i][2] = enregistrement[2].substring(2, enregistrement[2].length()-3);
			    	  i++;
			  	    }
		      }
		      raf.close();
	       }
		   catch (IOException e)
		   {
			   System.out.println("erreur dans: " + e);
		   }
		   return retour;
	}

}
