/*
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package ui;

import java.awt.Dimension;
import java.awt.Font;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.io.FileWriter;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextPane;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.text.BadLocationException;
import javax.swing.text.MutableAttributeSet;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class Editeur extends JFrame implements ActionListener
{
	/**
	 * 
	 */
	public static final int EN_BRAILLE = 1;
	public static final int EN_NOIR = 2;
	public static final int BRAILLE_ET_NOIR = 3;
	
	private static final long serialVersionUID = 1L;
	private JLabel lFichier = new JLabel("Fichier: ");
	private JPanel panneauAffichage = new JPanel();
	private JTextPane resultat = new JTextPane();
	private JScrollPane scrollRes;
	private JPanel lesBoutons = new JPanel();
	private JButton btEnregistrer = new JButton("Enregistrer");
	private JButton btFermer = new JButton("Fermer");
	private String fichier = null;
	
	public Editeur()
	{
		super("Editeur");
		panneauAffichage.setPreferredSize(new Dimension(500,400));
		
		btEnregistrer.addActionListener(this);
		btFermer.addActionListener(this);
		lesBoutons.add(btEnregistrer);
		lesBoutons.add(btFermer);

		resultat.setText("");
		//resultat.paintImmediately(0,0,panneauAffichage.getWidth(),panneauAffichage.getHeight());
		
		scrollRes = new JScrollPane (resultat);
		scrollRes.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
		scrollRes.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		scrollRes.setPreferredSize(new Dimension(450,300));
		
		panneauAffichage.add(scrollRes);
		add("North",lFichier);
		add("Center",panneauAffichage);
		add("South",lesBoutons);
		
	}
	
	/*public JTextPane donneZoneTexte()
	{
		return resultat;
	}*/
	public void actionPerformed(ActionEvent evt)
	{
		if(evt.getSource()==btEnregistrer)
		{
			EnregistrerFichier();
		}
		else if (evt.getSource() == btFermer)
		{
			this.dispose();
		}
	}
	
	private void EnregistrerFichier()
	{
		try
		{
			FileWriter raf = new FileWriter(fichier);
			raf.write(resultat.getText());
			raf.close();
		}
		catch (IOException e)
		{
			System.out.println("erreur dans: " + e);
		}
	}
	
	public void AfficheFichier(String nomFichier,int mode)
    {
	    fichier = nomFichier;
	    lFichier.setText(lFichier.getText() + fichier);
		//Prparation des styles pour le JTextPane
	    StyledDocument doc = resultat.getStyledDocument();
	    
	    //En Braille
	    //Style style = zoneTexte.addStyle("EnBraille", null);
	    MutableAttributeSet attrs = resultat.getInputAttributes();
	    Font fonteBraille = new Font("Braille Antoine", Font.PLAIN, 20);
	    Font fonteNoir = new Font("Courier", Font.PLAIN, 20);
	    //StyleConstants.setForeground(attrs, Color.red); ok
	
	    switch(mode)
	    {
	    	case EN_NOIR:
	    	{
		    	  StyleConstants.setFontFamily(attrs, fonteNoir.getFamily());
		    	  StyleConstants.setFontSize(attrs,18);
		    	  break;
	    	}
	    	default:
	    	{
		    	  StyleConstants.setFontFamily(attrs, fonteBraille.getFamily());
		    	  StyleConstants.setFontSize(attrs,15);
		    	  break;
	    	}
	    }
		resultat.setText("");
	    try
	      {
	      RandomAccessFile raf = new RandomAccessFile(nomFichier, "r");
	      String ligne;
	      while ( (ligne = raf.readLine()) != null )
		  	{
	    	  doc.insertString(doc.getLength(), ligne + "\n", attrs);
	  	    }
	      }
		   catch (BadLocationException ble)
		    {
		  	    System.err.println("Impossible d'afficher le texte");
		  	}
		   catch (IOException e)
		     {
		     System.out.println("erreur dans: " + e);
		     }
	    }	    
}
