/************************************************************************
 *
 *  Application.java
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright: 2002-2005 by Henrik Just
 *
 *  All Rights Reserved.
 * 
 *  Version 0.4.1a (2005-10-04) 
 *
 */
 
 // Warning: This code is a total mess currently; will be cleaned up asap

package writer2latex;

import java.io.File;
import java.io.FileOutputStream;
import java.io.FileInputStream;
import java.io.IOException;
//import java.net.URL;
import java.util.Enumeration;
import java.util.Locale;
import java.text.Collator;
//import javax.xml.parsers.ParserConfigurationException;
//import org.xml.sax.SAXException;
import org.w3c.dom.Element;

//import org.openoffice.xmerge.Convert;
import org.openoffice.xmerge.ConvertData;
import org.openoffice.xmerge.Document;
import org.openoffice.xmerge.converter.xml.OfficeDocument;
import org.openoffice.xmerge.converter.xml.sxc.SxcDocument;
import org.openoffice.xmerge.converter.xml.sxw.SxwDocument;

import writer2latex.util.Misc;
import writer2latex.util.Config;
import writer2latex.util.L10n;
import writer2latex.office.*;
import writer2latex.xmerge.SxiDocument;
import writer2latex.xhtml.XhtmlDocument;
//import writer2latex.latex.*;

/**
 * <p>Commandline utility to convert an OpenOffice.org Writer XML file to a LaTeX file<.</p>
 * <p>The code is based on org.openoffice.xmerge.test.Driver</p>
 */
public final class Application {
    // Version number and date of Writer2LaTeX
    private static final String VERSION = "0.4.1a";
    private static final String DATE = "2005-10-04";
	
    public static String getVersion() { return VERSION; }
    public static String getDate() { return DATE; }
	
    /**  Based on command-line parameters. */
    private boolean bRecurse = false;
    private String sOutputFormat = null;
    private String toMime = null;
    private String sTemplateFileName = null;
    private String sFileName = null; // may be a directory or a file
    private String sOutPathName = null;
    private String sOutFileName = null;
    private String sOutFileExtension = null;
    private String sConfigFileName = null;
	
    private XhtmlDocument template = null;

    private Config config;
    L10n l10n;
    boolean bBatch = false;
    String sDefaultLang = null;
    String sDefaultCountry = null;

    /* Mthodes d'accs
     * 
     */
    public void setsOutputFormat(String of)
    {
    	sOutputFormat = of;
    }
    
    public void setsOutFileExtension(String ofe)
    {
    	sOutFileExtension = ofe;
    }
    
    public void settoMime(String tm)
    {
    	toMime = tm; //MIMETypes.XHTML_MATHML
    }
    
    public void setsFileName(String source)
    {
    	sFileName = source;
    }
    
    public void setsOutPathName(String opn)
    {
    	sOutPathName = opn;
    }
    
    public void setsOutFileName(String ofn)
    {
    	sOutFileName = ofn;
    }
	
    /**
     *  Converts the document
     *
     *  @throws  IllegalArgumentException  If an argument is invalid.
     */
     public void doConversion() {
         config = new Config();

         if (sConfigFileName != null) {
             File f = new File(sConfigFileName);
             if (!f.exists()) {
                 System.err.println("The configuration file '"+sConfigFileName+"' does not exist.");
             }
             else {
                 try {
                     config.read(new FileInputStream(sConfigFileName));
                 } catch (Throwable t) {
                     System.err.println("I had trouble reading the configuration file "+sConfigFileName);
                     t.printStackTrace();
                 }
             }
        }

        // Set locale for directory conversion
        l10n = new L10n();
        sDefaultLang = System.getProperty("user.language");
        sDefaultCountry = System.getProperty("user.country");
        l10n.setLocale(sDefaultLang, sDefaultCountry);

        File f = new File(sFileName);

        // Make sure the input file/directory  actually exists and can be read
        // before using it
        if (!f.exists()) {
            System.out.println("I'm sorry, I can't find "+sFileName);
            System.exit(1);
        }
        if (!f.canRead()) {
            System.out.println("I'm sorry, I can't read "+sFileName);
            System.exit(1);
        }
	
        // Read the template
        if (sTemplateFileName!=null) {
            template = new XhtmlDocument("Template",XhtmlDocument.XHTML10);
            try {
                template.read(new FileInputStream(sTemplateFileName));
            }
            catch (Throwable t) {
                t.printStackTrace();
                template = null;
            }
        }

        // Convert the file/directory
        if (f.isDirectory()) { convertDirectory(f,sOutPathName); }
        else if (f.isFile()) { convertFile(f,sOutPathName); }
    }

    private String convertFile(File file,String sOutPathName) {
        String sFileName = file.getName();
        String sLocalOutFileName = bBatch ? Misc.removeExtension(sFileName) : sOutFileName;
        System.out.println("Converting "+sFileName);
        // If filename ends with .xml, we suppose that it's flat xml (and is Writer)
        boolean bFlat = sFileName.toLowerCase().endsWith(".xml");
        // Determine the type of document by the extension:
        boolean bCalc = sFileName.toLowerCase().endsWith(".sxc");
        boolean bImpress = sFileName.toLowerCase().endsWith(".sxi");
        if (!bCalc && !bImpress && !bFlat && !sFileName.toLowerCase().endsWith(".sxw")) {
            System.out.println("--> Ignored; not an OOo document");
            return null;
        }

        ConvertData dataOut = null;
		
        // Create and use the converter
        // No longer uses the XMerge interface
        // Somewhat messy, should be changed if XMerge is discarded
        OfficeDocument oooDoc;
        if (bCalc) {
            oooDoc = new SxcDocument(sFileName);
        }
        else if (bImpress) {
            oooDoc = new SxiDocument(sFileName);
        }
        else {
            oooDoc = new SxwDocument(sFileName);
        }

        try {
            FileInputStream fis = new FileInputStream(file);
            oooDoc.read(fis,!bFlat);
        }
        catch (IOException e) {
            System.out.println("Oops, there was an error reading "+sFileName);
            return null;
            //e.printStackTrace();
        }

        try {
        	/* Je comment epour garder juste le xhtml
            if (toMime.equals(MIMETypes.LATEX)) {
                writer2latex.latex.ConverterPalette converter
                    = new writer2latex.latex.ConverterPalette((SxwDocument)oooDoc,config);
                converter.setOutFileName(sLocalOutFileName); 
                dataOut = converter.convert();
            }
            else if (toMime.equals(MIMETypes.BIBTEX)) {
                writer2latex.bibtex.DocumentSerializerImpl converter
                    = new writer2latex.bibtex.DocumentSerializerImpl((SxwDocument)oooDoc);
                converter.setOutFileName(sLocalOutFileName); 
                dataOut = converter.serialize();
            }
            else*/
        	if (toMime.equals(MIMETypes.XHTML)) {
                writer2latex.xhtml.DocumentSerializerImpl converter
                    = new writer2latex.xhtml.DocumentSerializerImpl(oooDoc,
                            XhtmlDocument.XHTML10, config);
                converter.setOutFileName(sLocalOutFileName);
                if (template!=null) { converter.setTemplate(template); } 
                dataOut = converter.serialize();
            }
            else if (toMime.equals(MIMETypes.XHTML_MATHML)) {
                writer2latex.xhtml.DocumentSerializerImpl converter
                    = new writer2latex.xhtml.DocumentSerializerImpl(oooDoc,
                            XhtmlDocument.XHTML_MATHML, config); 
                converter.setOutFileName(sLocalOutFileName); 
                if (template!=null) { converter.setTemplate(template); } 
                dataOut = converter.serialize();
            }
            else if (toMime.equals(MIMETypes.XHTML_MATHML_XSL)) {
                writer2latex.xhtml.DocumentSerializerImpl converter
                    = new writer2latex.xhtml.DocumentSerializerImpl(oooDoc,
                            XhtmlDocument.XHTML_MATHML_XSL, config); 
                converter.setOutFileName(sLocalOutFileName); 
                if (template!=null) { converter.setTemplate(template); } 
                dataOut = converter.serialize();
            }
        }
        catch (Exception e) {
            System.out.println("Conversion failed");
            e.printStackTrace();
        }

        // TODO: Should do some further checking on the feasability of writing
        // the directory and the files.
        File dir = new File(sOutPathName);
        if (!dir.exists()) { dir.mkdirs(); }
        
        Enumeration docEnum = dataOut.getDocumentEnumeration();
        while (docEnum.hasMoreElements()) {
            Document docOut      = (Document)docEnum.nextElement();
            String fileName      = sOutPathName+docOut.getFileName();
            try {
                FileOutputStream fos = new FileOutputStream(fileName);
                docOut.write(fos);
                fos.flush();
                fos.close();
            } catch (Exception writeExcept) {
                System.out.println("\nThere was an error writing out file <" +
                    fileName + ">");
                writeExcept.printStackTrace();
            }
        }

        return sLocalOutFileName + sOutFileExtension;
    }

    private void convertDirectory(File dir,String sOutPathName) {
        bBatch = true;
        // Convert files and directories in the directory dir

        // Create index page (with header/footer); currently always use xhtml 1.0 strict
        XhtmlDocument htmlDoc = new XhtmlDocument("index",XhtmlDocument.XHTML10);
        htmlDoc.setEncoding(config.xhtmlEncoding());
        htmlDoc.setNoDoctype(config.xhtmlNoDoctype());
        if (template!=null) { htmlDoc.readFromTemplate(template); }
        else { htmlDoc.createHeaderFooter(); }

        org.w3c.dom.Document htmlDOM = htmlDoc.getContentDOM();

        // Use directory name as title
        htmlDoc.getTitleNode().appendChild( htmlDOM.createTextNode(dir.getName()) );

        // Declare charset (we need this for xhtml because we have no <?xml ... ?>)
        // if (nType==XhtmlDocument.XHTML10) {
            Element meta = htmlDOM.createElement("meta");
            meta.setAttribute("http-equiv","Content-Type");
            meta.setAttribute("content","text/html; charset="+htmlDoc.getEncoding().toLowerCase());
            htmlDoc.getHeadNode().appendChild(meta);
        // }
		
        // Add link to stylesheet
        if (config.xhtmlCustomStylesheet().length()>0) {
            Element htmlStyle = htmlDOM.createElement("link");
            htmlStyle.setAttribute("rel","stylesheet");
            htmlStyle.setAttribute("type","text/css");
            htmlStyle.setAttribute("media","all");
            htmlStyle.setAttribute("href",config.xhtmlCustomStylesheet());
            htmlDoc.getHeadNode().appendChild(htmlStyle);
        }

        // Add uplink to header and footer.
        Element header = htmlDoc.getHeaderNode();
        if (config.getXhtmlUplink().length()>0) {
            Element a = htmlDOM.createElement("a");
            a.setAttribute("href",config.getXhtmlUplink());
            a.appendChild(htmlDOM.createTextNode(l10n.get(L10n.UP)));
            header.appendChild(htmlDOM.createTextNode("["));
            header.appendChild(a);
            header.appendChild(htmlDOM.createTextNode("] "));
        }
        else {
            header.appendChild(htmlDOM.createTextNode("["+l10n.get(L10n.UP)+"]"));
        }
        header.appendChild(htmlDOM.createElement("hr"));
		
        Element footer = htmlDoc.getFooterNode();
        footer.appendChild(htmlDOM.createElement("hr"));
        if (config.getXhtmlUplink().length()>0) {
            Element a = htmlDOM.createElement("a");
            a.setAttribute("href",config.getXhtmlUplink());
            a.appendChild(htmlDOM.createTextNode(l10n.get(L10n.UP)));
            footer.appendChild(htmlDOM.createTextNode("["));
            footer.appendChild(a);
            footer.appendChild(htmlDOM.createTextNode("] "));
        }
        else {
            footer.appendChild(htmlDOM.createTextNode("["+l10n.get(L10n.UP)+"]"));
        }
		
        // Add heading
        if (sOutPathName.length()>0) {
            Element h1 = htmlDOM.createElement("h1");
            htmlDoc.getContentNode().appendChild(h1);
            String sSeparator = File.separator;
            if (sSeparator.equals("\\")) { sSeparator="\\\\"; }
            String sHeading = sOutPathName.substring(0,sOutPathName.length()-1)
                                          .replaceAll(sSeparator," - ");
            h1.appendChild(htmlDOM.createTextNode(sHeading));
        }
		
        // Get and sort the directory
        File[] contents = dir.listFiles();
        int nLen = contents.length;
        Collator collator = Collator.getInstance(new Locale(sDefaultLang,sDefaultCountry));
        for (int i = 0; i<nLen; i++) {
            for (int j = i+1; j<nLen ; j++) {
                File entryi = contents[i];
                File entryj = contents[j];
                if (collator.compare(entryi.getName(), entryj.getName()) > 0) {
                    contents[i] = entryj;
                    contents[j] = entryi;
                }
            }
        }


        // Traverse subdirectories, if allowed
        if (bRecurse) {
            boolean bUseIcon = config.getXhtmlDirectoryIcon().length()>0;
            for (int i=0; i<nLen; i++) {
                if (contents[i].isDirectory()) {
                    config.setOption("xhtml_uplink","../index.html");
                    convertDirectory(contents[i],sOutPathName+contents[i].getName()+File.separator);
                    Element p = htmlDOM.createElement("p");
                    htmlDoc.getContentNode().appendChild(p);
                    if (bUseIcon) {
                        Element img = htmlDOM.createElement("img");
                        p.appendChild(img);
                        img.setAttribute("src",config.getXhtmlDirectoryIcon());
                        img.setAttribute("alt","Directory icon"); // todo: localize
                        p.appendChild(htmlDOM.createTextNode(" "));
                    }
                    Element a = htmlDOM.createElement("a");
                    p.appendChild(a);
                    a.setAttribute("href",Misc.makeHref(contents[i].getName()+"/index.html"));
                    a.appendChild(htmlDOM.createTextNode(contents[i].getName()));
                }
            }
        }

        // Traverse documents
        boolean bUseIcon = config.getXhtmlDocumentIcon().length()>0;
        for (int i=0; i<nLen; i++) {
            if (contents[i].isFile()) {
                config.setOption("xhtml_uplink","index.html");
                String sLinkFile = convertFile(contents[i],sOutPathName);
                if (sLinkFile!=null) {
                    Element p = htmlDOM.createElement("p");
                    htmlDoc.getContentNode().appendChild(p);
                    if (bUseIcon) {
                        Element img = htmlDOM.createElement("img");
                        p.appendChild(img);
                        img.setAttribute("src",config.getXhtmlDocumentIcon());
                        img.setAttribute("alt","Document icon"); // todo: localize
                        p.appendChild(htmlDOM.createTextNode(" "));
                    }
                    Element a = htmlDOM.createElement("a");
                    p.appendChild(a);
                    a.setAttribute("href",Misc.makeHref(sLinkFile));
                    a.appendChild(htmlDOM.createTextNode(Misc.removeExtension(sLinkFile)));
                }
            }
        }

        // Write out the index file
        File outdir = new File(sOutPathName);
        if (!outdir.exists()) { outdir.mkdirs(); }
        
        String sFileName = sOutPathName+htmlDoc.getFileName();
        try {
            FileOutputStream fos = new FileOutputStream(sFileName);
            htmlDoc.write(fos);
            fos.flush();
            fos.close();
        } catch (Exception writeExcept) {
            System.out.println("\nThere was an error writing out file <" +
                sFileName + ">");
            writeExcept.printStackTrace();
        }

    }

    /**
     *  Display usage.
     *//*
    private static void showUsage(String msg) {
        System.out.println();
        System.out.println("This is Writer2LaTeX, Version " + VERSION 
                           + " (" + DATE + ")");
        System.out.println();
        if (msg != null) System.out.println(msg);
        System.out.println();
        System.out.println("Usage:");
        System.out.println("   java -jar <path>/writer2latex.jar <options> <document> [<output path/file name>]");
        System.out.println("where <options> is one of the following:");
        System.out.println("   [-latex] [-config <configuration file>]");
        System.out.println("   -bibtex");
        System.out.println("   -xhtml [-config <configuration file>]");
        System.out.println("   -xhtml+mathml [-config <configuration file>]");
        System.out.println("   -xhtml+mathml+xsl [-config <configuration file>]");
    }*/


    /**
     *  Parse command-line arguments.
     *
     *  @param  args  Array of command line arguments.
     *
     *  @throws  IllegalArgumentException  If an argument is invalid.
     *
    private void parseCommandLine(String args[])
        throws IllegalArgumentException {

        if (args.length == 0) {
            throw new IllegalArgumentException();
        }

        int i = 0;
        String sArg;

        sArg = getArg(i,args);
        if ("-recurse".equals(sArg)) {
            bRecurse = true;
            i++;
        }

        sArg = getArg(i,args);
        if ("-xhtml".equals(sArg)) {
            sOutputFormat = "xhtml";
            sOutFileExtension = ".html";
            toMime = MIMETypes.XHTML;
            i++;
        } 
        else if ("-xhtml+mathml".equals(sArg)) {
            sOutputFormat = "xhtml";
            sOutFileExtension = ".xhtml";
            toMime = MIMETypes.XHTML_MATHML;
            i++;
        } 
        else if ("-xhtml+mathml+xsl".equals(sArg)) {
            sOutputFormat = "xhtml";
            sOutFileExtension = ".xml";
            toMime = MIMETypes.XHTML_MATHML_XSL;
            i++;
        } 
        else if ("-bibtex".equals(sArg)) {
            sOutputFormat = "BibTeX";
            sOutFileExtension = ".bib";
            toMime = MIMETypes.BIBTEX;
            i++;
        }
        else if ("-latex".equals(sArg)) {
            sOutputFormat = "LaTeX";
            sOutFileExtension = ".tex";
            toMime = MIMETypes.LATEX;
            i++;
        }
        else { // assume LaTeX as default
            sOutputFormat = "LaTeX";
            toMime = MIMETypes.LATEX;
        }

        sArg = getArg(i,args);
        if ("-config".equals(sArg)) {
            i++;
            sConfigFileName = getArg(i++,args);
        }
		
        sArg = getArg(i,args);
        if ("-template".equals(sArg)) {
            i++;
            sTemplateFileName = getArg(i++,args);
        }

        sFileName = getArg(i++,args);
		
        String sFullOutFileName;
        if (i<args.length) { sFullOutFileName = getArg(i,args); }
        else { sFullOutFileName = Misc.removeExtension(sFileName); }
        if (sFullOutFileName.endsWith(File.separator)) { // directory only
            sOutPathName=sFullOutFileName;
            sOutFileName = (new File(sFileName)).getName();
        }
        else { // directory and filename
            File f = new File(sFullOutFileName);
            sOutPathName = f.getParent();
            if (sOutPathName==null) { sOutPathName=""; } else { sOutPathName+=File.separator; }
            sOutFileName = f.getName();
        }
        sOutFileName = Misc.removeExtension(sOutFileName);

        System.out.println();
        System.out.println("This is Writer2" + sOutputFormat
            + ", Version " + VERSION + " (" + DATE + ")");
        System.out.println();

    }*/


    /**
     *  Extract the next argument from the array, while checking to see
     *  that the array size is not exceeded.  Throw a friendly error
     *  message in case the arg is missing.
     *
     *  @param  i     Argument index.
     *  @param  args  Array of command line arguments.
     *
     *  @return  The argument with the specified index.
     *
     *  @throws  IllegalArgumentException  If an argument is invalid.
     */
    private String getArg(int i, String args[])
        throws IllegalArgumentException {

        if (i < args.length)
            return args[i];
        else throw new
            IllegalArgumentException("I'm sorry, the commandline ended abnormally");
    }
	

}
