<?xml version='1.0' encoding="ISO-8859-1" ?>
<!--
 * NAT - An universal Translator
 * Copyright (C) 2005 Bruno Mascret
 * Contact: bmascret@free.fr

 * former authors: Frdric Schwebel, Bruno Mascret
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-->

<!DOCTYPE xsl:stylesheet
  SYSTEM "mmlents/windob.dtd"
[
  <!ENTITY % table_braille PUBLIC "table braille" "./tablesBraille/Brltab.ent">
  %table_braille;
  <!ENTITY quad    "&ThickSpace;"> <!-- espace -->
  <!ENTITY neq     "&ne;"> <!-- different de -->
  <!ENTITY epsilon "&epsiv;"> <!-- epsilon -->
  <!ENTITY empty "&emptyv;"> <!-- endemble vide -->
  <!ENTITY ldots   "&mldr;"> <!-- points de suspension -->
  <!ENTITY hat     "&Hat;"> <!-- signe d'angle -->
  <!ENTITY espace  "&#254;"><!-- espace  generer-->
  <!ENTITY coupe   "&#255;"><!-- endroit ou on peut couper un equation-->
]>

<xsl:stylesheet version="1.0"
xmlns:xsl='http://www.w3.org/1999/XSL/Transform' 
xmlns:saxon='http://icl.com/saxon'
xmlns:m='http://www.w3.org/1998/Math/MathML'
xmlns:lit='espacelit'
xmlns:doc='espaceDoc'>

<xsl:output method="text" encoding="ISO-8859-1" indent="no"/>
<xsl:variable name="dbk"> <!-- caractere de debut de bloc -->
   <xsl:choose>
      <xsl:when test="$norme='1'">
        <xsl:text>&pt56;</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>&pt26;</xsl:text>
      </xsl:otherwise>
   </xsl:choose>
</xsl:variable>

<xsl:variable name="fbk"> <!-- caractere de fin de bloc -->
   <xsl:choose>
      <xsl:when test="$norme='1'">
        <xsl:text>&pt23;</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>&pt35;</xsl:text>
      </xsl:otherwise>
   </xsl:choose>
</xsl:variable>

<!-- ****** FONCTION de COUPURE D'EQUATION *********** -->

<xsl:template name="coupure">

    <xsl:param name="equation" />
    <xsl:param name="long_ligne" select="0" />
    <xsl:variable name="long_dispo" select="number($longueur)-number($long_ligne)" />
    <xsl:choose>
           <xsl:when test="string-length(translate($equation,'&coupe;','')) &lt; ($long_dispo+1)">
               <xsl:value-of select="translate($equation,'&coupe;','')" />
               <!-- hop, c'est la fin -->
           </xsl:when>
           <xsl:when test="(string-length(substring-before($equation,'&coupe;')) &lt; $long_dispo) and contains ($equation,'&coupe;')">
              <!-- on affiche la chaine avant le point de coupure -->
              <xsl:value-of select="substring-before($equation,'&coupe;')" />
              <!-- et on rappelle la meme fonction avec la chaine d'apres en parametre -->
              <xsl:call-template name="coupure">
                  <xsl:with-param name="equation">
                      <xsl:value-of select="substring-after($equation,'&coupe;')" />
                  </xsl:with-param>
                  <xsl:with-param name="long_ligne">
                      <xsl:value-of select="number($long_ligne)+string-length(substring-before($equation,'&coupe;'))" />
                  </xsl:with-param>
              </xsl:call-template>
           </xsl:when>
           <xsl:otherwise>
           <!-- sinon, faut couper l'equation avec le pt5 et on recommence a la ligne-->
               <xsl:text>&pt5;&coupe;</xsl:text>
               <xsl:call-template name="coupure">
                  <xsl:with-param name="equation">
                      <xsl:value-of select="$equation" />
                  </xsl:with-param>
                  <xsl:with-param name="long_ligne" select="0" />
              </xsl:call-template>
          </xsl:otherwise>
      </xsl:choose>
</xsl:template>

<!-- ******************** PROGRAMME ****************** -->

<!-- *******************************************
   On met les chars de debut et fin de document
     ******************************************* -->
<xsl:template match="/">
    <xsl:value-of select="$debut" />
    <xsl:apply-templates select="@*|*|text()|processing-instruction()"/>
    <xsl:value-of select="$fin" />
</xsl:template>

<!-- *******************************************
 Tout ce qui n'est pas trait est ressorti tel quel (attention  l'encodage)
     ******************************************* -->
<xsl:template match="@*|*|text()|processing-instruction()" priority="-1">
    <xsl:copy>
      <xsl:apply-templates select="@*|*|text()|processing-instruction()"/>
    </xsl:copy>
</xsl:template>

<!-- on vire les commentaires et les annotations mathtype -->
<xsl:template match="comment()|m:annotation">
</xsl:template>

<!-- pour que les memes rules s'appliquent avec ou sans un fils semantics -->
<xsl:template match="m:math[m:semantics]">
	<xsl:variable name="eqqn">
		<xsl:apply-templates />
	</xsl:variable>
	<!-- pour virer les lignes vides -->
	<xsl:value-of select="translate($eqqn,'&#13;&#10; ','')"/>
</xsl:template>

<xsl:template match="m:semantics|m:math">
   <xsl:variable name="enfants"> <!-- pour l'amelioration le nom de la variable est "teste" -->
      <xsl:value-of select="count(m:mrow/descendant::*)" />
   </xsl:variable>
   <!-- enfants <xsl:value-of select="$enfants" /> -->
   
<!-- tentative d'amelioration avortee c'est trop le bazar 

si on a un systeme d'equations, on a qu'un seul child au 1er mrow, c'est un autre mrow
      donc c'est complexe avec un seul enfant, pareil avec mfrac et matble mais sinon ca depend juste du nb d'enfants
   <xsl:variable name="enfants">
      <xsl:choose>
        <xsl:when test="($teste=1) and (contains ('mfracmrowmtable',name(semantics/mrow/child::*[1])))">
        a ce moment-la on met 5 (valeur bidon) pour dire que c'est complexe
           <xsl:value-of select="5" />
        </xsl:when>
        <xsl:otherwise>
           <xsl:value-of select="$teste" />
        </xsl:otherwise>
      </xsl:choose>
   </xsl:variable>
-->
   <xsl:variable name="charspt6">
       <!-- caracteres auxquels il faut rajouter un pt6 selon qu'on est en abrg ou pas -->
       <xsl:choose>
         <xsl:when test="$abrege=1">abcdefghijklmnopqrstuvwxyz1234567890</xsl:when>
         <xsl:when test="$abrege=0">1234567890</xsl:when>
       </xsl:choose>
   </xsl:variable>

   <xsl:variable name="equation">
	<xsl:choose>
	   <xsl:when test="(local-name(m:mrow/child::*[1])='mn') and 
	   					not(count(m:mrow/m:mtext)= 0 ) and	
	   					(((count(m:mrow/child::*))-1)=(count(m:mrow/m:mi)+count(m:mrow/m:mtext)))">
	      <!-- cas particulier d'un nombre + espaces + des lettres = c'est un nb + une unite (2 km ou 5 s par exemple) -->
	      <xsl:text>&pt6;</xsl:text><xsl:apply-templates select="m:mrow/m:mn" />
	      <xsl:text>&espace;</xsl:text>
	      <xsl:if test="($abrege='1') and contains($charspt6,substring(m:mrow/m:mi[1],1,1))">
	        <xsl:text>&pt6;</xsl:text> <!-- pt6 si abrege et si la 1ere lettre de l'unite est minuscule -->
	      </xsl:if>
	      <xsl:apply-templates select="m:mrow/m:mi" />
	   </xsl:when>
	   <xsl:when test="$enfants &lt; 3 or not(local-name(child::*[1])='mrow')">
	      <xsl:choose>
               <xsl:when test="contains($charspt6,substring(child::*[1],1,1))"> <!-- nombre ou lettre simple -->
           	      <xsl:text>&pt6;</xsl:text><xsl:apply-templates/>
               </xsl:when>
               <!-- <xsl:when test="$enfants>1 and contains($charspt6,substring(semantics/mrow/child::*[1],1,1))"> and $enfants>0 ca marchait pas pour 2pi faut pt6pt3
           	      <xsl:text>&pt6;</xsl:text><xsl:value-of select="$enfants"/><xsl:apply-templates/>
               </xsl:when> -->
	           <xsl:when test="($enfants=2) and contains($charspt6,substring(m:mrow/child::*[2],1,1)) and contains ('+-', m:mrow/child::*[1])">
           	      <!-- cas d'un nb negatif -->
           	      <xsl:text>&pt6;</xsl:text><xsl:apply-templates/>
               </xsl:when>
			   <xsl:when test="($enfants=2) and contains(concat($charspt6,'ABCDEFGHIJKLMNOPQRSTUVWXYZ'),substring(m:mrow/child::*[1],1,1))">
           	      <!-- cas d'une expression simple genre 2x ou 2pi ou AB -->
           	      <xsl:text>&pt6;&pt3;</xsl:text><xsl:apply-templates/>
               </xsl:when>
               <xsl:when test="local-name(m:mrow/child::*[1])='msqrt'">
                  <!-- cas particulier d'une racine care simple -->
                  <xsl:text>&pt6;&pt3;</xsl:text><xsl:apply-templates/>
               </xsl:when>
               <xsl:otherwise>
                 <!-- sinon pas  pt6 ni pt3 pour les ensembles, les majuscules... -->
                  <xsl:apply-templates />
               </xsl:otherwise>
            </xsl:choose>
         </xsl:when>
         <xsl:otherwise>
               <xsl:text>&pt6;&pt3;</xsl:text><xsl:apply-templates/>
         </xsl:otherwise>
      </xsl:choose>
<!--
		<xsl:if test="(count(.//mo)>1) or (count(.//mo[1]/preceding-sibling::*)>0)">
	  <xsl:text>&pt3;</xsl:text>
	</xsl:if>
-->
    </xsl:variable>
    
    <!-- on enleve les espaces, les line feed et tabs de l'equation -->
    <xsl:variable name="eqn2">
      <xsl:value-of select="translate($equation,'&#13;&#10; ','')" />
    </xsl:variable>
    
    <xsl:variable name="longeqn"> <!-- longueur effective de l'equation -->
      <xsl:value-of select="string-length(translate($eqn2,'&coupe;',''))" />
    </xsl:variable>
    
    <!-- ****** Affichage final de l'expression ****** -->
    <xsl:value-of disable-output-escaping="yes" select="$avant"/>
    <xsl:choose>
      <xsl:when test="$longeqn>$longueur and $coupons='1'">
       <xsl:variable name="eqn3">
         <xsl:call-template name="coupure">
             <xsl:with-param name="equation" select="$eqn2" />
         </xsl:call-template>
       </xsl:variable>
       <xsl:value-of select="translate($eqn3,'&espace;&coupe;&#13;&#10; ',' &#10;')" />
      </xsl:when>
      <xsl:otherwise>
         <xsl:value-of select="translate($eqn2,'&espace;&coupe;',' ')" />
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$apres"/>
    <!-- ****** Fin Affichage final ****** -->
</xsl:template>

<!-- la suite tait commente (espaces) -->
<xsl:template match="m:ms">
  <xsl:choose>
    <xsl:when test=".='&thinsp;' or .='&ThickSpace;'">
    </xsl:when>
    <xsl:otherwise>
	<xsl:apply-templates />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="none|m:mspace">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="m:mrow|m:mtr">
	  <xsl:apply-templates/>
</xsl:template>

<!-- espaces transforms en pt3 si entre deux chiffres et laisss sinon-->
<xsl:template match="m:mtext">
	<!-- probleme avec codeUS o pt3=' a fait planter le translate donc
	solution provisoire qui le restera certainement longtemps : utiliser une variable -->
	<xsl:variable name="pt3">&pt3;</xsl:variable>
	<xsl:choose>
		<xsl:when test="not(count(child::*)=0)">
		<!-- le noeud texte est pas vide alors on applique les templates filles et alea jacta est -->
			<xsl:value-of select="text()" />
			<xsl:apply-templates />
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="(local-name(preceding::*[1])='mn') and (local-name(following::*[1])='mn')">
		   			<!-- <xsl:value-of select="translate(.,'&ThickSpace;&quad; &thinsp;','&pt3;&pt3;&pt3;&pt3;')" /> -->
		   			<xsl:value-of select="translate(.,'&ThickSpace;&quad; &thinsp;',concat($pt3,$pt3,$pt3,$pt3))" />
		   		</xsl:when>
		   		<xsl:when test="string-length(translate(following::*[1],'?!;:',''))=0">
		   		<!-- on a un espace de mise en page avant une ponctuation finale qui disparat en braille -->
		   			<xsl:value-of select="translate(.,'&ThickSpace;&quad; &thinsp;','')" />
		   		</xsl:when>
		   		<xsl:otherwise>
		 			<xsl:value-of select="translate(.,'&ThickSpace;&quad; &thinsp;','&espace;&espace;&espace;')" />
		 		</xsl:otherwise>
		 	</xsl:choose>
		 </xsl:otherwise>
	</xsl:choose>
</xsl:template>
<!-- *******************************************
       Template match mi
     ******************************************* -->
<xsl:template match="m:mi">
  <xsl:choose>
  
<!-- Euro fait  l'arrache car l'entit &euro; n'est pas dans la DTD mathml -->
	 <xsl:when test=".='euro'">
	   <xsl:text>&pt46;e</xsl:text>
	 </xsl:when>

<!-- forcissation de cle majuscule -->
<!-- Bruno: pour avoir le double prfixe (on s'en fout en math, faudra virer a et le faire marcher)-->
     <xsl:when test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZ',substring(string(.),1,1))">
	  <xsl:text>&pt46;</xsl:text>
	  <xsl:choose>
	    <xsl:when test="string-length(.)>1 and contains('ABCDEFGHIJKLMNOPQRSTUVWXYZ',substring(string(.),2,1))">
	      <xsl:text>&pt46;</xsl:text>
	    </xsl:when>
	  </xsl:choose>
	  <xsl:value-of select="translate(.,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','&pt1;&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;&pt2456;&pt1346;&pt13456;&pt1356;')" />
     </xsl:when>
<!--&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;w&pt1436;&pt13456;&pt1356;-->
<!-- &circ est signe "rond" (f rond g) ou degres d'angle -->
     <xsl:when test=".='&circ;'">
      <xsl:choose>
	  <xsl:when test="local-name(parent::*)='msup'">
          <!-- est-ce un signe de degre ? -->
  	    <xsl:text>o</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
   	     <xsl:text>&pt456;&pt3456;</xsl:text> <!-- f rond g -->
	  </xsl:otherwise>
      </xsl:choose>
     </xsl:when>

<!-- pts de suspension -->
     <xsl:when test=".='&mldr;'or .='&vellip;' or .='&dtdot;' or .='&ldots;' or .='&ctdot;'">
       <xsl:text>&pt2;&pt2;&pt2;</xsl:text>
     </xsl:when>

<!-- puce remplacee par 3 points aussi -->
     <xsl:when test=".='&bullet;'">
       <xsl:text>&pt2;&pt2;&pt2;</xsl:text>
     </xsl:when>

<!-- on vire les espaces -->
     <xsl:when test=".='&ZeroWidthSpace;'">
       <xsl:text></xsl:text>
     </xsl:when>
     <xsl:when test=".='&ThickSpace;'">
       <xsl:text></xsl:text>
     </xsl:when>

<!-- Ensembles RZCQND infini vide -->

    <xsl:when test=".='&Copf;'"> <!-- complexes -->
       <xsl:text>&pt46;&pt46;c</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Ropf;'"> <!-- rels -->
       <xsl:text>&pt46;&pt46;r</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Nopf;'"> <!-- entiers naturels -->
       <xsl:text>&pt46;&pt46;n</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Qopf;'"> <!--Q -->
       <xsl:text>&pt46;&pt46;q</xsl:text>
    </xsl:when>
    <xsl:when test=".='&Zopf;'"> <!-- Z -->
       <xsl:text>&pt46;&pt46;z</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Dopf;'"> <!-- dcimaux -->
       <xsl:text>&pt46;&pt46;d</xsl:text>
    </xsl:when>

    <xsl:when test=".='&infin;'"> <!-- infini -->
       <xsl:text>&pt45;c</xsl:text>
    </xsl:when>

    <xsl:when test=".='&emptyv;'"> <!-- ensemble vide -->
	<xsl:text>&pt4;&pt3456;</xsl:text>
    </xsl:when>

<!-- Caracteres grecs minuscules -->

    <xsl:when test=".='&alpha;'">
       <xsl:text>&pt45;a</xsl:text>
    </xsl:when>

    <xsl:when test=".='&beta;'">
       <xsl:text>&pt45;b</xsl:text>
    </xsl:when>

    <xsl:when test=".='&gamma;'">
       <xsl:text>&pt45;g</xsl:text>
    </xsl:when>

    <xsl:when test=".='&delta;'">
       <xsl:text>&pt45;d</xsl:text>
    </xsl:when>

    <xsl:when test=".='&epsiv;'"> <!-- epsilon -->
       <xsl:text>&pt45;e</xsl:text>
    </xsl:when>

    <xsl:when test=".='&zeta;'">
       <xsl:text>&pt45;z</xsl:text>
    </xsl:when>

    <xsl:when test=".='&eta;'">
       <xsl:text>&pt45;h</xsl:text>
    </xsl:when>

    <xsl:when test=".='&theta;'">
       <xsl:text>&pt45;j</xsl:text>
    </xsl:when>

    <xsl:when test=".='&iota;'">
       <xsl:text>&pt45;i</xsl:text>
    </xsl:when>

    <xsl:when test=".='&kappa;'">
       <xsl:text>&pt45;k</xsl:text>
    </xsl:when>

    <xsl:when test=".='&lambda;'">
       <xsl:text>&pt45;l</xsl:text>
    </xsl:when>

    <xsl:when test=".='&mu;'">
       <xsl:text>&pt45;m</xsl:text>
    </xsl:when>

    <xsl:when test=".='&nu;'">
       <xsl:text>&pt45;n</xsl:text>
    </xsl:when>

    <!-- ajouter xi pt45 et x -->
    <xsl:when test=".='&xi;'">
       <xsl:text>&pt45;x</xsl:text>
    </xsl:when>

    <!-- <xsl:when test=".='o;'">  omicron, pas d'entite
       <xsl:text>&pt45;o</xsl:text>
    </xsl:when> -->

    <xsl:when test=".='&pi;'">
       <xsl:text>&pt45;p</xsl:text>
    </xsl:when>

    <xsl:when test=".='&rho;'">
       <xsl:text>&pt45;r</xsl:text>
    </xsl:when>

    <xsl:when test=".='&sigma;'">
       <xsl:text>&pt45;s</xsl:text>
    </xsl:when>

    <xsl:when test=".='&tau;'">
       <xsl:text>&pt45;t</xsl:text>
    </xsl:when>

    <xsl:when test=".='&upsilon;'">
       <xsl:text>&pt45;u</xsl:text>
    </xsl:when>

    <xsl:when test=".='&phi;'">
       <xsl:text>&pt45;f</xsl:text>
    </xsl:when>

    <xsl:when test=".='&chi;'"> <!-- ou plutt khi?,  vrif -->
       <xsl:text>&pt45;q</xsl:text>
    </xsl:when>

    <xsl:when test=".='&psi;'">
       <xsl:text>&pt45;y</xsl:text>
    </xsl:when>

    <xsl:when test=".='&omega;'">
       <xsl:text>&pt45;w</xsl:text>
    </xsl:when>

<!-- Caracteres grecs majuscules -->

    <xsl:when test=".='&Agr;'">
       <xsl:text>&pt4;a</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Bgr;'">
       <xsl:text>&pt4;b</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Gamma;'">
       <xsl:text>&pt4;g</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Delta;'">
       <xsl:text>&pt4;d</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Egr;'">
       <xsl:text>&pt4;e</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Zgr;'">
       <xsl:text>&pt4;z</xsl:text>
    </xsl:when>

    <xsl:when test=".='&EEgr;'">
       <xsl:text>&pt4;h</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Theta;'">
       <xsl:text>&pt4;j</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Igr;'">
       <xsl:text>&pt4;i</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Kgr;'">
       <xsl:text>&pt4;k</xsl:text>
    </xsl:when>

    <!-- La traduction du lambda majuscule est celle-ci
       xsl:text &pt4;l /xsl:text
       mais il risque(ait) plutot d'tre utilis comme signe de
       produit vectoriel donc on met(tait) cette traduction (dans le V1)
       <xsl:when test=".='&Lambda;'">
       <xsl:text>&pt45;&pt236;</xsl:text> -->
    <xsl:when test=".='&Lambda;'">
	 <xsl:text>&pt4;l</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Mgr;'">
       <xsl:text>&pt4;m</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Ngr;'">
       <xsl:text>&pt4;n</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Xi;'">
       <xsl:text>&pt4;w</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Ogr;'">
       <xsl:text>&pt4;o</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Pi;'">
       <xsl:text>&pt4;p</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Rgr;'">
       <xsl:text>&pt4;r</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Sigma;'">
       <xsl:text>&pt4;s</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Tgr;'">
       <xsl:text>&pt4;t</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Upsilon;'">
       <xsl:text>&pt4;u</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Phi;'">
       <xsl:text>&pt4;f</xsl:text>
    </xsl:when>

    <!-- le khi est  vrifier -->
    <xsl:when test=".='&KHgr;'">
       <xsl:text>&pt4;q</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Psi;'">
       <xsl:text>&pt4;y</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Omega;'">
       <xsl:text>&pt4;w</xsl:text>
    </xsl:when>

<!-- lettres rondes utilises essentiellement en gomtrie (police Euclid math one et NOUVEAU : Math12) -->
    <xsl:when test=".='&Ascr;'">
        <xsl:text>&pt46;&pt5;a</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Cscr;'">
        <xsl:text>&pt46;&pt5;c</xsl:text>
    </xsl:when>

	<xsl:when test=".='&Lscr;'">
        <xsl:text>&pt46;&pt5;l</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Pscr;'"> <!-- dans math12 -->
        <xsl:text>&pt46;&pt5;p</xsl:text>
    </xsl:when>
    
    <xsl:when test=".='&wp;'"> <!-- P script majuscule -->
        <xsl:text>&pt46;&pt5;p</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Sscr;'">
        <xsl:text>&pt46;&pt5;s</xsl:text>
    </xsl:when>

    <xsl:when test=".='&Vscr;'">
        <xsl:text>&pt46;&pt5;v</xsl:text>
    </xsl:when>

    <xsl:when test=".='&ell;'"> <!-- l script minuscule -->
        <xsl:text>&pt5;l</xsl:text>
    </xsl:when>

    <xsl:when test=".='&fscr;'"> <!-- f script minuscule -->
        <xsl:text>&pt5;f</xsl:text>
    </xsl:when>

    <xsl:otherwise>
	<xsl:value-of select="normalize-space(.)"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- *******************************************
       Template match mn (chiffres)
     ******************************************* -->

<xsl:template match="m:mn">
<!-- il faut mettre un point 6 devant un ponctuation en dernire position -->
	<xsl:variable name="dernier" select="substring(.,string-length(.))" />
<!-- probleme avec codeUS o pt3=' a fait planter le translate donc
	solution provisoire qui le restera certainement longtemps : utiliser une variable -->	
	<xsl:variable name="pt3">&pt3;</xsl:variable>
	<xsl:choose>
	  <xsl:when test="string-length(translate($dernier,'.:;?!',''))= 0">
	    <xsl:value-of select="translate(substring(.,1,string-length(.)-1),',.1234567890','&pt2;&pt2;&pt16;&pt126;&pt146;&pt1456;&pt156;&pt1246;&pt12456;&pt1256;&pt246;&pt3456;')" />
	    <xsl:text>&pt6;</xsl:text><xsl:value-of select="translate($dernier,'.:;?!',concat($pt3,'&pt25;&pt23;&pt26;&pt235;'))" />
	  </xsl:when>
	  <xsl:otherwise>
        <xsl:value-of select="translate(.,',.1234567890','&pt2;&pt2;&pt16;&pt126;&pt146;&pt1456;&pt156;&pt1246;&pt12456;&pt1256;&pt246;&pt3456;')" />
      </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- *******************************************
       Template match mo
     ******************************************* -->

<xsl:template match="m:mo">
  <xsl:choose>

    <!-- ajout 10 mars 2004 -->
    <!-- ce tilde peut tre aussi "sinusode" pt4pt2356 mais c'est rare alors zut -->
    <xsl:when test=".='&tilde;'"> <!-- signe de fct polynomiale -->
    	<xsl:text>&pt4;&pt456;&pt25;</xsl:text>
    </xsl:when>
    
    <!--Ajout 17 fevrier 2004 -->
    <xsl:when test=".='&nabla;'"> <!-- nabla = delta  l'envers -->
    	<xsl:text>&pt45;&pt4;d</xsl:text>
    </xsl:when>
    
    <!-- Ajout de qq oublis 25 juin 2002 -->
    <xsl:when test=".='&triangleright;'">
      <xsl:text>tridroite</xsl:text>
    </xsl:when>
    
    <xsl:when test=".='&triangleleft;'">
      <xsl:text>trigauche</xsl:text>
    </xsl:when>
    
    <xsl:when test=".='%' or .='&percnt;'">
      <xsl:text>&pt6;&pt3456;&pt46;&pt3456;</xsl:text>
      <!-- pt6 au debut mais ptete qu'il en faut pas -->
    </xsl:when>
    
    <xsl:when test=".='&permil;'">
      <xsl:text>&pt6;&pt3456;&pt46;&pt3456;&pt3456;</xsl:text>
      <!-- pt6 au debut mais ptete qu'il en faut pas -->
    </xsl:when>
    
    <!-- ** NN les signes de ponctuation sont  faire prcder par un pt6-->
    <!-- ponctuation traite: ; -->
    <xsl:when test=".=';'">
      <xsl:text>&pt6;&pt23;</xsl:text>
    </xsl:when>

<!-- &circ est signe "rond" (f rond g) ou degres d'angle -->
     <xsl:when test=".='&circ;'">
      <xsl:choose>
	  <xsl:when test="local-name(parent::*)='msup'">
          <!-- est-ce un signe de degre ? -->
  	    <xsl:text>o</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
   	     <xsl:text>&pt456;&pt3456;</xsl:text> <!-- f rond g -->
	  </xsl:otherwise>
      </xsl:choose>
     </xsl:when>

<!-- ** gomtrie *************************************** -->

    <xsl:when test=".='&par;'"> <!-- parallele a -->
      <xsl:text>&pt4;&pt1256;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&perp;'"> <!-- perpendiculaire a -->
      <xsl:text>&pt45;&pt1256;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&frown;'"> <!-- signe d'arc -->
      <xsl:text>&pt4;&pt25;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&ang;' or .='&hat;' or .='&Hat;'"> <!-- signes d'angles -->
      <xsl:text>&pt45;&pt25;</xsl:text>
    </xsl:when>

    <!-- une truc qui ressemble  un petit delta majuscule: je le traduis pareil que delta-->
    <xsl:when test=".='&bigtriangleup;'">
      <xsl:text>&pt4;d</xsl:text>
     </xsl:when>

    
    <!-- sin, cos et tan ont des signes speciaux pour ancienne norme -->
    <xsl:when test="(.='sin') and ($norme='2')">
        <xsl:text>&pt356;</xsl:text>
    </xsl:when>
    <xsl:when test="(.='cos') and ($norme='2')">
        <xsl:text>&pt346;</xsl:text>
    </xsl:when>
    <xsl:when test="(.='sin') and ($norme='2')">
        <xsl:text>&pt2346;</xsl:text>
    </xsl:when>

    <!-- </A INCLURE FAUTE MAJUSCULE> -->

    <!-- ** Flches *************************************** -->

    <!-- pour les fleches vers la droite, symbole different selon si c'est
    une fleche "normale" ou un vecteur -->

    <xsl:when test=".='&rarr;' or .='&xrarr;'"> <!-- Fleche horiz. droite -->
      <xsl:choose>
	  <xsl:when test="local-name(parent::*)='mover'">
          <!-- est-ce une fleche de vecteur ? -->
  	    <xsl:text>&pt46;&pt25;</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
   	     <xsl:text>&pt456;&pt156;</xsl:text> <!-- fleche normale -->
	  </xsl:otherwise>
      </xsl:choose>
    </xsl:when>

    <xsl:when test=".='&larr;' or .='&xlarr;'"> <!-- Fleche horiz. gauche -->
	<!-- rien... -->
    </xsl:when>

    <xsl:when test=".='&map;'"> <!-- Fleche associe -->
	<xsl:text>&pt5;&pt156;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&nearr;'"> <!-- Fleche croissant -->
	<xsl:text>&pt45;&pt156;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&searr;'"> <!-- Fleche decroissant -->
	<xsl:text>&pt46;&pt156;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&rArr;'"> <!-- Fleche implique -->
	<xsl:text>&pt25;&pt2;</xsl:text>
    </xsl:when>
    
    <xsl:when test=".='&lArr;'"> <!-- Fleche implique gauche-->
	<xsl:text>&pt5;&pt25;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&cdot;'"> <!-- produit scalaire -->
	<xsl:choose>
	  <xsl:when test="$norme='1'">
	    <xsl:text>&pt5;&pt35;</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
   	    <xsl:text>&pt5;&pt236;</xsl:text>
	  </xsl:otherwise>
	</xsl:choose>
    </xsl:when>

    <xsl:when test=".='.'"> <!-- multiplication ou unite -->
    <!-- si dernire position, point de ponctuation pt6pt3 -->
	<xsl:choose>
	  <xsl:when test="count(following-sibling::*)=0">
	    <xsl:text>&pt6;&pt3;</xsl:text>
	  </xsl:when>
	  <xsl:when test="$norme='1'">
	    <xsl:text>&pt35;</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
   	    <xsl:text>&pt236;</xsl:text>
	  </xsl:otherwise>
	</xsl:choose>
    </xsl:when>
    
    <xsl:when test=".='?'">
    <!--  priori il s'agit uniquement d'une ponctuation de fin donc point6 -->
    	<xsl:text>&pt6;&pt26;</xsl:text>
    </xsl:when>
    
    
    <xsl:when test=".='!'">
    <!-- si dernire position avec espace avant, point d'exclamation -->
    <!-- factorielle ou "unique" si "il existe" avant-->
	<xsl:choose>
		<xsl:when test="contains ('&ThickSpace;&quad; &thinsp;',preceding::*[1]) and count(following-sibling::*)=0">
			<xsl:text>&pt6;&pt235;</xsl:text>
		</xsl:when>
	    <xsl:when test="preceding-sibling::*[1]='&exist;'">
	        <xsl:choose>
	            <xsl:when test="$norme='1'">
		  	    <xsl:text>&pt6;&pt235;</xsl:text>
		    </xsl:when>
		    <xsl:otherwise>
		     	    <xsl:text>&pt235;</xsl:text>
		    </xsl:otherwise>
		</xsl:choose>
	    </xsl:when>
	    <xsl:otherwise> <!-- factorielle -->
	        <xsl:choose>
		    <xsl:when test="$norme='1'">
		       <xsl:text>&pt456;&pt35;</xsl:text>
		    </xsl:when>
		    <xsl:otherwise>
		        <xsl:text>&pt456;&pt236;</xsl:text>
		    </xsl:otherwise>
		</xsl:choose>
	    </xsl:otherwise>
      </xsl:choose>
    </xsl:when>

    <xsl:when test=".='&wedge;'"> <!-- produit vectoriel -->
        <xsl:choose>
	  <xsl:when test="$norme='1'">
	    <xsl:text>&pt45;&pt35;</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
   	    <xsl:text>&pt45;&pt236;</xsl:text>
	  </xsl:otherwise>
	</xsl:choose>
    </xsl:when>

    <!-- ya un truc que je capte pas ici: Msg erreur:name expected (found "<") -->
    <!-- j'ai enfin capt: certaine entity ne peuvent tre mise sous la forme "&#nombre;" ex &amp -->

    <xsl:when test=".='&Verbar;'"> <!-- double barre vert. -->
	<xsl:text>&pt45;&pt123456;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&forall;'"> <!-- quelque soit -->
	<xsl:text>&pt456;&pt34;</xsl:text>
    </xsl:when>
    <xsl:when test=".='&exist;'"> <!-- il existe -->
	<xsl:text>&pt456;&pt16;</xsl:text>
    </xsl:when>
    <xsl:when test=".='&hArr;'"> <!-- equivalent a -->
	<xsl:text>&pt5;&pt25;&pt2;</xsl:text>
    </xsl:when>


    <xsl:when test=".='&sum;'"> <!-- somme algbrique-->
	<xsl:text>&pt4;s</xsl:text>
    </xsl:when>
    <xsl:when test=".='&prod;'"> <!-- produit -->
	<xsl:text>&pt4;p</xsl:text>
    </xsl:when>

<!--    <xsl:when test=".='&PI;'">
	<xsl:text>&pt4;p</xsl:text>
    </xsl:when>
    Un jour cette entite fut generee par mathtype. Paix a son ame.
-->
    <xsl:when test=".='('"> <!-- parenthse gauche , matrice -->
        <xsl:choose>
	        <xsl:when test="local-name(following-sibling::*[1]/child::*[1])='mtable'"> <!-- matrice-->
	          <!--  <xsl:choose>
	              <xsl:when test="$norme='1'">
	                <xsl:text>&pt4;&pt236;</xsl:text>
	              </xsl:when>
	              <xsl:otherwise>
	                <xsl:text>&pt45;&pt26;</xsl:text>
	              </xsl:otherwise>
	            </xsl:choose>
	            ON MET RIEN -->
	        </xsl:when>
	        <xsl:otherwise>
      	            <xsl:choose>
	              <xsl:when test="$norme='1'">
	                <xsl:text>&pt236;</xsl:text>
	              </xsl:when>
	              <xsl:otherwise>
	                <xsl:text>&pt26;</xsl:text>
	              </xsl:otherwise>
	            </xsl:choose>
	        </xsl:otherwise>
	</xsl:choose>
    </xsl:when>

    <xsl:when test=".=')'"> <!-- parenthse droite , matrice -->
        <xsl:choose>
	        <xsl:when test="local-name(preceding-sibling::*[1]/child::*[1])='mtable'"> <!-- matrice-->
	            <!-- <xsl:choose>
	              <xsl:when test="$norme='1'">
	                <xsl:text>&pt4;&pt356;</xsl:text>
	              </xsl:when>
	              <xsl:otherwise>
	                <xsl:text>&pt45;&pt35;</xsl:text>
	              </xsl:otherwise>
	            </xsl:choose>
	            on met rien -->
	        </xsl:when>
	        <xsl:otherwise>
      	            <xsl:choose>
	              <xsl:when test="$norme='1'">
	                <xsl:text>&pt356;</xsl:text>
	              </xsl:when>
	              <xsl:otherwise>
	                <xsl:text>&pt35;</xsl:text>
	              </xsl:otherwise>
	            </xsl:choose>
	        </xsl:otherwise>
	</xsl:choose>
    </xsl:when>

    <xsl:when test=".='{'"> <!-- accolade gauche , systme d'quation-->
        <xsl:choose>
	        <xsl:when test="local-name(following-sibling::*[1])='mtable'"> <!-- systme grande accolade-->
		  <!-- si on a un systeme d'equations, pas de signe d'accolade -->
	            <!-- <xsl:choose>
	              <xsl:when test="$norme='1'">
	                <xsl:text>&pt4;&pt46;&pt236;</xsl:text>
	              </xsl:when>
	              <xsl:otherwise>
	                <xsl:text>&pt456;&pt26;</xsl:text>
	              </xsl:otherwise>
	            </xsl:choose> -->
	        </xsl:when>
	        <xsl:otherwise>
      	            <xsl:choose>
	              <xsl:when test="$norme='1'">
	                <xsl:text>&pt46;&pt236;</xsl:text>
	              </xsl:when>
	              <xsl:otherwise>
	                <xsl:text>&pt46;&pt26;</xsl:text>
	              </xsl:otherwise>
	            </xsl:choose>
	        </xsl:otherwise>
	</xsl:choose>
    </xsl:when>

    <xsl:when test=".='}'"> <!-- accolade droite -->
      <xsl:choose>
         <xsl:when test="$norme='1'">
           <xsl:text>&pt46;&pt356;</xsl:text>
         </xsl:when>
         <xsl:otherwise>
           <xsl:text>&pt46;&pt35;</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
    </xsl:when>

    <!-- trouver le code du grand crochet
    <xsl:when test=".='}'"> grand crochet ouvert **NN
       <xsl:text>&pt4;&pt12356;</xsl:text>
    </xsl:when>

    <xsl:when test=".='}'"> grand crochet ferm **NN
       <xsl:text>&pt4;&pt23456;</xsl:text>
    </xsl:when>
    -->

    <!-- **** Ensembles ************************************ -->

    <xsl:when test=".='&cup;'"> <!-- union -->
       <xsl:text>&pt4;&pt235;</xsl:text>
    </xsl:when>

    <!-- grande union -->

    <!-- grande intersection -->

    <xsl:when test=".='&cap;'"> <!-- intersection -->
       <xsl:text>&pt45;&pt235;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&isin;'"> <!-- appartient a -->
       <xsl:text>&pt45;&pt16;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&isinv;'"> <!-- appartient a bis -->
       <xsl:text>&pt45;&pt16;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&notin;'"> <!-- n appartient pas -->
       <xsl:text>&pt45;&pt34;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&sub;'"> <!-- inclus dans (sens strict)-->
       <xsl:text>&pt46;&pt16;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&vnsub;'"> <!-- n'est pas inclus dans (sens strict)-->
       <xsl:text>&pt46;&pt34;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&sube;'"> <!-- inclus dans (sens large)-->
       <xsl:text>&pt4;&pt46;&pt16;</xsl:text>
    </xsl:when>

    <!--<xsl:when test=".='&vnsube;'">  !!!n'est pas inclus dans (sens large); cette entit n'est pas dans mathtype
       <xsl:text>&pt4;&pt46;&pt34;</xsl:text>
    </xsl:when>
    -->

    <!-- **** PB PB PB les 2 entits suivantes-->
    <xsl:when test=".='&sup;'"> <!-- inclus dans (sens strict)-->
       <xsl:text>&pt4;&pt16;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&supe;'"> <!-- inclus dans (sens large)-->
       <xsl:text>(inclus_au_sens_large(NDNN))</xsl:text>
    </xsl:when>

    <!-- la norme ne donne pas la traduction pour supe et sup (a inclus (large) b; a inclus b (strict) -->

    <!-- remember the vase of quotient d'ensembles p.21 &pt4;&pt256;-->

    <!-- </A INCLURE> -->

    <!-- **** quations-inquations-systmes ************************ -->

    <xsl:when test=".='&ne;'"> <!-- non egal -->
       <xsl:text>&coupe;&pt46;&pt2356;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&neq;'"> <!-- non egal bis -->
       <xsl:text>&coupe;&pt46;&pt2356;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&approx;' or .='&cong;' or .='&sim;'"> <!-- environ egal -->
       <xsl:text>&coupe;&pt5;&pt2356;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&le;'"> <!-- inferieur ou egal -->
       <xsl:text>&coupe;&pt45;&pt126;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&ge;'"> <!-- superieur ou egal -->
       <xsl:text>&coupe;&pt45;&pt345;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&amp;lt;'"> <!-- strict. inferieur -->
       <xsl:text>&coupe;&pt46;&pt126;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&gt;'"> <!-- strict. superieur -->
       <xsl:text>&coupe;&pt46;&pt345;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&equiv;'"> <!-- = a trois barres, relation de congruence-->
	<xsl:text>&coupe;&pt2356;&pt2356;</xsl:text> <!--CHIMIE pt123456-->
    </xsl:when>

    <!-- ***** barre horizontale, derivees ****** -->

    <xsl:when test=".='&horbar;' or .='&amp;macr;'"> <!-- barre horizontale -->
       <xsl:text>&pt456;&pt25;</xsl:text>
    </xsl:when>

    <!-- l'apostrophe (caractere 39) est change en .
      pour les derivees (point 3) -->
    <xsl:when test='.="&apos;" or .="&prime;"'>
       <xsl:text>&pt3;</xsl:text>
    </xsl:when>
    <xsl:when test='.="&apos;&apos;" or .="&prime;&prime;"'>
       <xsl:text>&pt3;&pt3;</xsl:text>
    </xsl:when>
    <xsl:when test='.="&apos;&apos;&apos;" or .="&prime;&prime;&prime;"'>
       <xsl:text>&pt3;&pt3;&pt3;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&part;'"> <!-- derivee partielle -->
       <xsl:text>&pt4;&pt1456;</xsl:text>
    </xsl:when>

    <!-- **** Oprateurs NN****************************************** -->

    <!--pour les symboles divise et multiplie, on regarde si l'operateur
    precedent est une fraction auquel cas il faut doubler
    le signe dans l'ancienne norme -->

    <xsl:when test=".='&times;'">

	<xsl:choose>
	  <xsl:when test="$norme='1'">
	    <xsl:text>&coupe;&pt35;</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
	    <!-- abandon du doublage du signe
	        <xsl:when test="name(preceding-sibling::*[1])='mfrac'"> -->

      	      <xsl:text>&coupe;&pt236;</xsl:text>

	  </xsl:otherwise>
	</xsl:choose>
    </xsl:when>

    <xsl:when test=".='&divide;' or .='/'">
	    <xsl:text>&coupe;&pt256;</xsl:text>
	    <!-- abandon du doublage du signe
	        <xsl:when test="name(preceding-sibling::*[1])='mfrac'"> -->
    </xsl:when>

<!-- avant on avait a mais pour la table WebCBFr1252 o on a plusieurs caractres pour = a chie, d'o la sparation    
    <xsl:when test=".='=' or .='+' or .='-'">
	    <xsl:text>&coupe;</xsl:text><xsl:value-of select="translate(.,'=+-','&pt2356;&pt235;&pt36;')" />
    </xsl:when> -->

    <xsl:when test=".='='">
	    <xsl:text>&coupe;&pt2356;</xsl:text>
    </xsl:when>

    <xsl:when test=".='+'">
	    <xsl:text>&coupe;&pt235;</xsl:text>
    </xsl:when>

    <xsl:when test=".='-'">
	    <xsl:text>&coupe;&pt36;</xsl:text>
    </xsl:when>

    <xsl:when test=".='&plusmn;'">
    	<xsl:text>&coupe;&pt235;&pt36;</xsl:text>
    </xsl:when>
    
    <xsl:when test=".='*'"> <!-- Nouvelle norme ! -->
       <xsl:choose>
         <xsl:when test="$norme='1'">
           <xsl:text>&pt6;&pt35;</xsl:text>
         </xsl:when>
         <xsl:otherwise>
           <xsl:text>&pt35;</xsl:text>
         </xsl:otherwise>
       </xsl:choose>
       <!-- L'ETOILE N'EST PAS UNE MULTIPLICATION, MAIS UN SYMBOLE D'ENSEMBLE ex. R* -->
     </xsl:when>
    <!-- **** l c'est les trucs auxquels on peut faire correspondre directement un pt123456 NN************* -->
    <xsl:otherwise>
           <xsl:value-of select="translate(.,':,[]&int;|&verbar;','&pt25;&pt2;&pt12356;&pt23456;&pt12346;&pt123456;&pt123456;')" />
	<!-- prime,x,divis,/,=,*,+,-,[,],intgrale,|,barre verticale simple -->
	<!-- l'apostrophe (caractere 39) est change en . pour les derivees (point 3)-->
	<!-- la barre | (aussi appelee &verbar;) est change en & pour les modules de cplx -->
	<!-- : est traduit par pt25 ("tel que") -->

    </xsl:otherwise>
  </xsl:choose>

</xsl:template>

<!-- *********************************************************************************************************
         Racines carrees et nieme NN
     ******************************************* -->
<xsl:template match="m:msqrt">
    <xsl:text>&pt345;</xsl:text><!-- signe de racine -->
    <xsl:choose>
     	<xsl:when test="count(child::*[1]/descendant::*) &lt; 2 or (count(child::*[1]/child::*) &lt; 3 and ((local-name(child::*[1]/child::*[1])='mo')or (local-name(child::*[1]/child::*[1])='mn')))">
	  <xsl:apply-templates/> <!-- racine simple -->
	</xsl:when>
	<xsl:otherwise> <!-- racine complexe -->
	   <xsl:choose>
	     <xsl:when test="$norme='1'">
		<xsl:value-of select="$dbk" /> <!-- debut de bloc -->
     		<xsl:apply-templates/>
     		<xsl:value-of select="$fbk" />
     	     </xsl:when>
     	     <xsl:otherwise>
     		<xsl:apply-templates/>
     		<xsl:text>&pt23;</xsl:text>
     	     </xsl:otherwise>
     	   </xsl:choose>
     	 </xsl:otherwise>
     </xsl:choose>
</xsl:template>

<xsl:template match="m:mroot">
  <xsl:choose>
     <xsl:when test="$norme='1'"> <!-- signe nieme -->
       <xsl:text>&pt6;&pt34;</xsl:text>
     </xsl:when>
     <xsl:otherwise>
        <xsl:text>&pt56;</xsl:text>
     </xsl:otherwise>
  </xsl:choose>

  <xsl:apply-templates select="child::*[2]"/> <!-- exposant de la racine -->
  <xsl:text>&pt345;</xsl:text><!-- signe de racine -->
    <xsl:choose>
     	<xsl:when test="count(child::*[1]/child::*) &lt; 2 or (count(child::*[1]/child::*)=2 and local-name(child::*[1]/child::*[1])='mo')">
	<xsl:apply-templates select="child::*[1]"/> <!-- racine simple -->
	</xsl:when>
	<xsl:otherwise> <!-- racine complexe -->
	   <xsl:choose>
	     <xsl:when test="$norme='1'">
		<xsl:value-of select="$dbk" /> <!-- debut de bloc -->
     		<xsl:apply-templates select="child::*[1]"/>
     		<xsl:value-of select="$fbk" />
     	     </xsl:when>
     	     <xsl:otherwise>
     		<xsl:apply-templates select="child::*[1]"/>
     		<xsl:text>&pt23;</xsl:text>
     	     </xsl:otherwise>
     	   </xsl:choose>
     	 </xsl:otherwise>
     </xsl:choose>
</xsl:template>

<!-- *******************************************
         Fractions et trucs dessus-dessous NN
     ******************************************* -->

<xsl:template match="m:mfrac">
	<xsl:variable name="NonComplx">;+-=&rarr;&xrarr;&map;</xsl:variable>
	<xsl:variable name="complexe">
	<!-- la fraction necessite-t-elle des blocs ? -->
		<xsl:choose>
<!--			<xsl:when test="(following-sibling::*[1]='+' or following-sibling::*[1]='-' or following-sibling::*[1]='=' or count(following-sibling::*)=0) and (preceding-sibling::*[1]='+' or preceding-sibling::*[1]='-' or preceding-sibling::*[1]='=' or count(preceding-sibling::*)=0)"> -->
			<xsl:when test="(contains($NonComplx,following-sibling::*[1]) or count(following-sibling::*)=0) and (contains($NonComplx, preceding-sibling::*[1]) or count(preceding-sibling::*)=0)">
			  <xsl:text>non</xsl:text>
			</xsl:when>
			<xsl:otherwise>
			  <xsl:text>oui</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

     <!-- nouvelle norme : fraction encadree par des blocs si * ou / apres -->
     <xsl:if test="$complexe='oui'">
	         <xsl:value-of select="$dbk" />
     </xsl:if>

     <xsl:choose>
     	<xsl:when test="(count(child::*[1]/child::*) &lt; 2 and not(local-name(child::*[1]/child::*[1])='mfrac')) or (count(child::*[1]/child::*)=2 and contains('+-',child::*[1]/child::*[1]) and not(local-name(child::*[1]/child::*[2])='mfrac'))">
     	<!-- avant a la place contains y'avait name(child::*[1]/child::*[1]='mo') -->
     	<!-- numerateur simple donc pas de bloc -->
	         <xsl:apply-templates select="child::*[1]"/>
	</xsl:when>
	<xsl:otherwise>
	   <xsl:value-of select="$dbk" />
	   <xsl:apply-templates select="child::*[1]"/>
	   <xsl:value-of select="$fbk" />
	</xsl:otherwise>
     </xsl:choose>
     <xsl:text>&coupe;&pt256;</xsl:text> <!-- signe de division -->
      <xsl:choose>
     	<xsl:when test="(count(child::*[2]/child::*) &lt; 2 and not(local-name(child::*[2]/child::*[1])='mfrac')) or (count(child::*[2]/child::*)=2 and local-name(child::*[2]/child::*[1])='mo' and not(local-name(child::*[2]/child::*[2])='mfrac'))">
     	<!-- denominateur simple donc pas de bloc -->
	         <xsl:apply-templates select="child::*[2]"/>
	</xsl:when>
	<xsl:otherwise>
	   <xsl:value-of select="$dbk" />
	   <xsl:apply-templates select="child::*[2]"/>
	   <xsl:value-of select="$fbk" />
	</xsl:otherwise>
      </xsl:choose>
     <!-- fraction encadree par des blocs ou parentheses si * ou / apres -->
     <xsl:if test="$complexe='oui'">
	         <xsl:value-of select="$fbk" />
     </xsl:if>
</xsl:template>

<xsl:template match="m:mover">
	<xsl:choose>
	  <xsl:when test="local-name(parent::*)='mtext'">
		<!-- experimental ! si le parent est un mtext alors c'est diffrent mais c'est  dconseiller -->
		<xsl:apply-templates select="child::*[1]"/>
		<xsl:choose>
			<xsl:when test="contains('ABCDEFGHIJKLMNOPQRSTUVWXYZ',normalize-space(text()))">
	  			<xsl:text>&pt46;</xsl:text><xsl:value-of select="translate(text(),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','&pt1;&pt12;&pt14;&pt145;&pt15;&pt124;&pt1245;&pt125;&pt24;&pt245;&pt13;&pt123;&pt134;&pt1345;&pt135;&pt1234;&pt12345;&pt1235;&pt234;&pt2345;&pt136;&pt1236;&pt2456;&pt1346;&pt13456;&pt1356;')" />
     		</xsl:when>
     		<xsl:otherwise>
     			<xsl:value-of select="text()"/>
     		</xsl:otherwise>
     	</xsl:choose>
	  </xsl:when>
	  <xsl:otherwise>
		<!-- mover classique et prouv -->
		<xsl:apply-templates select="child::*[2]"/>
		<xsl:choose>
     	  <xsl:when test="count(child::*[1]/child::*) &lt; 2 or (count(child::*[1]/child::*)=2 and local-name(child::*[1]/child::*[1])='mo')
     	  or (count(child::*[1]/mi)=count(child::*[1]/child::*))">
     	  <!-- ce qu'il y a dessous est simple et il n'y a pas que des lettres-->
             <xsl:apply-templates select="child::*[1]"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$dbk" />
            <xsl:apply-templates select="child::*[1]"/>
            <xsl:value-of select="$fbk" />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="m:munder">
      <xsl:apply-templates select="child::*[1]"/>
      <!-- signe d'indice souscrit -->
      <xsl:choose>
        <xsl:when test="$norme='1'">
          <xsl:text>&pt26;&pt26;</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>&pt56;</xsl:text>
        </xsl:otherwise>
      </xsl:choose>

      <xsl:choose>
        <xsl:when test="count(child::*[2]/child::*) &lt; 2 or (count(child::*[2]/child::*)=2 and local-name(child::*[2]/child::*[1])='mo')">
        <!-- indice simple -->
          <xsl:apply-templates select="child::*[2]"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="$norme='1'">
              <xsl:value-of select="$dbk" />
              <xsl:apply-templates select="child::*[2]" />
              <xsl:value-of select="$fbk" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="child::*[2]" />
              <xsl:text>&pt23;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
</xsl:template>

<!-- <xsl:template match="m:munderover">
      <xsl:when test="child::*[1]='&int;'"> integrale NN
     	<xsl:apply-templates select="child::*[1]"/>
        <xsl:text>&pt26;</xsl:text>
	<xsl:apply-templates select="child::*[2]"/>
	<xsl:text>&pt34;</xsl:text>
	<xsl:apply-templates select="child::*[3]"/>
</xsl:template> -->

<xsl:template match="m:munderover">
   <xsl:choose>
     <xsl:when test="$norme='2' and child::*[1]='&int;'">
     <!-- integrale ancienne norme -->
     	<xsl:apply-templates select="child::*[1]"/>
	<xsl:apply-templates select="child::*[2]"/>
	<xsl:text>&pt2;</xsl:text>
	<xsl:apply-templates select="child::*[3]"/>
	<xsl:text>&pt2;</xsl:text>
     </xsl:when>
     <xsl:otherwise>
      <xsl:apply-templates select="child::*[1]"/>
      <!-- signe d'indice souscrit -->
      <xsl:choose>
        <xsl:when test="$norme='1'">
          <xsl:text>&pt26;&pt26;</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>&pt56;</xsl:text>
        </xsl:otherwise>
      </xsl:choose>

      <xsl:choose>
	<xsl:when test="count(child::*[2]/child::*) &lt; 2 or (count(child::*[2]/child::*)=2 and local-name(child::*[2]/child::*[1])='mo')">
	<!-- indice simple -->
	  <xsl:apply-templates select="child::*[2]"/>
	</xsl:when>
	<xsl:otherwise> <!-- indice complexe -->
	  <xsl:choose>
	    <xsl:when test="$norme='1'">
	       <xsl:value-of select="$dbk" />
	       <xsl:apply-templates select="child::*[2]"/>
	       <xsl:value-of select="$fbk" />
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:apply-templates select="child::*[2]"/>
	      <xsl:text>&pt23;</xsl:text>
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:otherwise>
      </xsl:choose>
      <!-- signe d'indice suscrit
      on encadre l'indice par des blocs ou une fin d'indice
      qq soit cet indice pour eviter les ambiguites-->
      <xsl:choose>
        <xsl:when test="$norme='1'">
          <xsl:text>&pt34;&pt34;</xsl:text>
          <xsl:value-of select="$dbk" />
          <xsl:apply-templates select="child::*[3]"/>
          <xsl:value-of select="$fbk" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>&pt34;</xsl:text>
          <xsl:apply-templates select="child::*[3]"/>
          <xsl:text>&pt23;</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
     </xsl:otherwise>
   </xsl:choose>
</xsl:template>

<!-- *******************************************
         Exposants et indices NN
     ******************************************* -->
<xsl:template match="m:msup">
        <xsl:apply-templates select="child::*[1]"/>
      <!-- on met pas de signe d'exposant si on a un degr ou un prime-->
        <xsl:if test="not(child::*[2]='&circ;') and not(child::*[2]='&prime;')">
                <xsl:text>&pt34;</xsl:text>
        </xsl:if>
        <xsl:choose>
          <xsl:when test="count(child::*[2]/child::*) &lt; 2 or (count(child::*[2]/child::*)=2 and local-name(child::*[2]/child::*[1])='mo')">
          <!-- exposant simple -->
             <xsl:apply-templates select="child::*[2]"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
              <xsl:when test="$norme='1'">
                <xsl:value-of select="$dbk" />
                <xsl:apply-templates select="child::*[2]"/>
                <xsl:value-of select="$fbk" />
              </xsl:when>
              <xsl:otherwise>
                <xsl:apply-templates select="child::*[2]"/>
                <xsl:text>&pt23;</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:otherwise>
       </xsl:choose>
</xsl:template>

<xsl:template match="m:msub">
     <xsl:apply-templates select="child::*[1]"/>
     <xsl:choose> <!-- signe d'indice -->
       <xsl:when test="$norme='1'">
           <xsl:text>&pt26;</xsl:text>
       </xsl:when>
       <xsl:otherwise>
          <xsl:text>&pt56;</xsl:text>
       </xsl:otherwise>
     </xsl:choose>

     <xsl:choose>
        <xsl:when test="count(child::*[2]/child::*) &lt; 2 or (count(child::*[2]/child::*)=2 and local-name(child::*[2]/child::*[1])='mo')">
        <!-- indice simple -->
           <xsl:apply-templates select="child::*[2]"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="$norme='1'">
              <xsl:value-of select="$dbk" />
              <xsl:apply-templates select="child::*[2]"/>
              <xsl:value-of select="$fbk" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="child::*[2]"/>
              <xsl:text>&pt23;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
     </xsl:choose>
</xsl:template>

<xsl:template match="m:msubsup">
<!-- maj 10/11/04 : selon le bouton choisi pour le subsup dans MathType, des fois c'est l'exposant
le deuxieme enfant, des fois c'est l'indice on est oblige de declarer les variables chacune au
niveau le plus eleve (donc de faire 2 choose au lieu d'un) sinon saxon voit plus les variables -->
   <xsl:variable name="indic">
     <xsl:choose>
       <xsl:when test="local-name(child::*[1])='mstyle'">
       	  <xsl:value-of select="3" />
       </xsl:when>
       <xsl:otherwise>
     	  <xsl:value-of select="2" />
       </xsl:otherwise>
     </xsl:choose>
   </xsl:variable>
   
   <xsl:variable name="exposant">
     <xsl:choose>
       <xsl:when test="local-name(child::*[1])='mstyle'">
       	  <xsl:value-of select="2" />
       </xsl:when>
       <xsl:otherwise>
     	  <xsl:value-of select="3" />
       </xsl:otherwise>
     </xsl:choose>
   </xsl:variable>

   <xsl:choose>
     <xsl:when test="$norme='2' and child::*[1]='&int;'">
     <!-- integrale ancienne norme -->
     	<xsl:apply-templates select="child::*[1]"/>
	 <xsl:apply-templates select="child::*[number($indic)]"/>
	 <xsl:text>&pt2;</xsl:text>
	 <xsl:apply-templates select="child::*[number($exposant)]"/>
	 <xsl:text>&pt2;</xsl:text>
    </xsl:when>
     <xsl:otherwise>
       <xsl:apply-templates select="child::*[1]"/>
       <!-- signe d'indice -->
       <xsl:choose>
        <xsl:when test="$norme='1'">
          <xsl:text>&pt26;</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>&pt56;</xsl:text>
        </xsl:otherwise>
       </xsl:choose>

       <xsl:choose>
	<xsl:when test="count(child::*[number($indic)]/child::*) &lt; 2 or (count(child::*[number($indic)]/child::*)=2 and local-name(child::*[number($indic)]/child::*[1])='mo')">
	<!-- indice simple -->
	      <xsl:apply-templates select="child::*[number($indic)]"/>
	</xsl:when>
	<xsl:otherwise> <!-- indice complexe -->
	  <xsl:choose>
	    <xsl:when test="$norme='1'">
	       <xsl:value-of select="$dbk" />
	       <xsl:apply-templates select="child::*[number($indic)]"/>
	       <xsl:value-of select="$fbk" />
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:apply-templates select="child::*[number($indic)]"/>
	      <xsl:text>&pt23;</xsl:text>
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:otherwise>
       </xsl:choose>
      <!-- signe d'exposant
      on encadre l'exposant par des blocs ou une fin d'exposant
      qq soit cet exposant pour eviter les ambiguites-->
      <xsl:choose>
        <xsl:when test="$norme='1'">
          <xsl:text>&pt34;</xsl:text>
          <xsl:value-of select="$dbk" />
          <xsl:apply-templates select="child::*[number($exposant)]"/>
          <xsl:value-of select="$fbk" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>&pt34;</xsl:text>
          <xsl:apply-templates select="child::*[number($exposant)]"/>
          <xsl:text>&pt23;</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
     </xsl:otherwise> <!-- fin de "si c pas une integrale ancienne norme" -->
  </xsl:choose>
</xsl:template>

<!-- **************************** systmes d'quations, matices, dterminants, etc.. ********************* -->
<xsl:template match="m:mtable"><!--mtr/mtd"-->
  <xsl:choose>
    <xsl:when test="preceding::*[1]='{'"><!-- c'est un systeme -->
      <xsl:for-each select="m:mtr/m:mtd">
        <xsl:apply-templates/>
	<xsl:if test="not(position()=last()) ">
	  <xsl:text>&pt6;&pt345;&coupe;</xsl:text>
	</xsl:if>
      </xsl:for-each>
    </xsl:when>
    
    <xsl:otherwise>
    <!-- <xsl:when test="preceding::*[1]='('"> c'est une matrice ou un tableau -->
      <xsl:text>&pt45;&pt236;</xsl:text>
      <xsl:for-each select="m:mtr">
      <xsl:for-each select="m:mtd">
        <xsl:apply-templates />
        <xsl:if test="not(position()=last()) ">
	   <xsl:text>&coupe;&espace;</xsl:text>
	</xsl:if>
      </xsl:for-each>
      <xsl:if test="not(position()=last()) ">
	  <xsl:text>&pt6;&pt345;&coupe;</xsl:text>
      </xsl:if>
      </xsl:for-each>
      <xsl:text>&pt45;&pt356;</xsl:text> <!-- fin de matrice -->
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="doc:doc">
	<xsl:apply-templates select="@*|*|text()|processing-instruction()" />
</xsl:template>

</xsl:stylesheet>